# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = ['OauthRoleAssignmentArgs', 'OauthRoleAssignment']

@pulumi.input_type
class OauthRoleAssignmentArgs:
    def __init__(__self__, *,
                 client_id: pulumi.Input[_builtins.str],
                 type: pulumi.Input[_builtins.str],
                 resource_set: Optional[pulumi.Input[_builtins.str]] = None,
                 role: Optional[pulumi.Input[_builtins.str]] = None):
        """
        The set of arguments for constructing a OauthRoleAssignment resource.
        :param pulumi.Input[_builtins.str] client_id: Client ID for the role to be assigned to
        :param pulumi.Input[_builtins.str] type: Role type to assign. This can be one of the standard Okta roles, such as `HELP_DESK_ADMIN`, or `CUSTOM`. Using custom requires the `resource_set` and `role` attributes to be set.
        :param pulumi.Input[_builtins.str] resource_set: Resource set for the custom role to assign, must be the ID of the created resource set.
        :param pulumi.Input[_builtins.str] role: Custom Role ID
        """
        pulumi.set(__self__, "client_id", client_id)
        pulumi.set(__self__, "type", type)
        if resource_set is not None:
            pulumi.set(__self__, "resource_set", resource_set)
        if role is not None:
            pulumi.set(__self__, "role", role)

    @_builtins.property
    @pulumi.getter(name="clientId")
    def client_id(self) -> pulumi.Input[_builtins.str]:
        """
        Client ID for the role to be assigned to
        """
        return pulumi.get(self, "client_id")

    @client_id.setter
    def client_id(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "client_id", value)

    @_builtins.property
    @pulumi.getter
    def type(self) -> pulumi.Input[_builtins.str]:
        """
        Role type to assign. This can be one of the standard Okta roles, such as `HELP_DESK_ADMIN`, or `CUSTOM`. Using custom requires the `resource_set` and `role` attributes to be set.
        """
        return pulumi.get(self, "type")

    @type.setter
    def type(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "type", value)

    @_builtins.property
    @pulumi.getter(name="resourceSet")
    def resource_set(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Resource set for the custom role to assign, must be the ID of the created resource set.
        """
        return pulumi.get(self, "resource_set")

    @resource_set.setter
    def resource_set(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "resource_set", value)

    @_builtins.property
    @pulumi.getter
    def role(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Custom Role ID
        """
        return pulumi.get(self, "role")

    @role.setter
    def role(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "role", value)


@pulumi.input_type
class _OauthRoleAssignmentState:
    def __init__(__self__, *,
                 client_id: Optional[pulumi.Input[_builtins.str]] = None,
                 label: Optional[pulumi.Input[_builtins.str]] = None,
                 resource_set: Optional[pulumi.Input[_builtins.str]] = None,
                 role: Optional[pulumi.Input[_builtins.str]] = None,
                 status: Optional[pulumi.Input[_builtins.str]] = None,
                 type: Optional[pulumi.Input[_builtins.str]] = None):
        """
        Input properties used for looking up and filtering OauthRoleAssignment resources.
        :param pulumi.Input[_builtins.str] client_id: Client ID for the role to be assigned to
        :param pulumi.Input[_builtins.str] label: Label of the role assignment
        :param pulumi.Input[_builtins.str] resource_set: Resource set for the custom role to assign, must be the ID of the created resource set.
        :param pulumi.Input[_builtins.str] role: Custom Role ID
        :param pulumi.Input[_builtins.str] status: Status of the role assignment
        :param pulumi.Input[_builtins.str] type: Role type to assign. This can be one of the standard Okta roles, such as `HELP_DESK_ADMIN`, or `CUSTOM`. Using custom requires the `resource_set` and `role` attributes to be set.
        """
        if client_id is not None:
            pulumi.set(__self__, "client_id", client_id)
        if label is not None:
            pulumi.set(__self__, "label", label)
        if resource_set is not None:
            pulumi.set(__self__, "resource_set", resource_set)
        if role is not None:
            pulumi.set(__self__, "role", role)
        if status is not None:
            pulumi.set(__self__, "status", status)
        if type is not None:
            pulumi.set(__self__, "type", type)

    @_builtins.property
    @pulumi.getter(name="clientId")
    def client_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Client ID for the role to be assigned to
        """
        return pulumi.get(self, "client_id")

    @client_id.setter
    def client_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "client_id", value)

    @_builtins.property
    @pulumi.getter
    def label(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Label of the role assignment
        """
        return pulumi.get(self, "label")

    @label.setter
    def label(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "label", value)

    @_builtins.property
    @pulumi.getter(name="resourceSet")
    def resource_set(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Resource set for the custom role to assign, must be the ID of the created resource set.
        """
        return pulumi.get(self, "resource_set")

    @resource_set.setter
    def resource_set(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "resource_set", value)

    @_builtins.property
    @pulumi.getter
    def role(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Custom Role ID
        """
        return pulumi.get(self, "role")

    @role.setter
    def role(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "role", value)

    @_builtins.property
    @pulumi.getter
    def status(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Status of the role assignment
        """
        return pulumi.get(self, "status")

    @status.setter
    def status(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "status", value)

    @_builtins.property
    @pulumi.getter
    def type(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Role type to assign. This can be one of the standard Okta roles, such as `HELP_DESK_ADMIN`, or `CUSTOM`. Using custom requires the `resource_set` and `role` attributes to be set.
        """
        return pulumi.get(self, "type")

    @type.setter
    def type(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "type", value)


@pulumi.type_token("okta:app/oauthRoleAssignment:OauthRoleAssignment")
class OauthRoleAssignment(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 client_id: Optional[pulumi.Input[_builtins.str]] = None,
                 resource_set: Optional[pulumi.Input[_builtins.str]] = None,
                 role: Optional[pulumi.Input[_builtins.str]] = None,
                 type: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        """
        Manages assignment of an admin role to an OAuth application
        		This resource allows you to assign an Okta admin role to a OAuth
        		service application. This requires the Okta tenant feature flag for this function to be enabled.

        ## Import

        ```sh
        $ pulumi import okta:app/oauthRoleAssignment:OauthRoleAssignment test <clientID>/<roleAssignmentID>
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] client_id: Client ID for the role to be assigned to
        :param pulumi.Input[_builtins.str] resource_set: Resource set for the custom role to assign, must be the ID of the created resource set.
        :param pulumi.Input[_builtins.str] role: Custom Role ID
        :param pulumi.Input[_builtins.str] type: Role type to assign. This can be one of the standard Okta roles, such as `HELP_DESK_ADMIN`, or `CUSTOM`. Using custom requires the `resource_set` and `role` attributes to be set.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: OauthRoleAssignmentArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Manages assignment of an admin role to an OAuth application
        		This resource allows you to assign an Okta admin role to a OAuth
        		service application. This requires the Okta tenant feature flag for this function to be enabled.

        ## Import

        ```sh
        $ pulumi import okta:app/oauthRoleAssignment:OauthRoleAssignment test <clientID>/<roleAssignmentID>
        ```

        :param str resource_name: The name of the resource.
        :param OauthRoleAssignmentArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(OauthRoleAssignmentArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 client_id: Optional[pulumi.Input[_builtins.str]] = None,
                 resource_set: Optional[pulumi.Input[_builtins.str]] = None,
                 role: Optional[pulumi.Input[_builtins.str]] = None,
                 type: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = OauthRoleAssignmentArgs.__new__(OauthRoleAssignmentArgs)

            if client_id is None and not opts.urn:
                raise TypeError("Missing required property 'client_id'")
            __props__.__dict__["client_id"] = client_id
            __props__.__dict__["resource_set"] = resource_set
            __props__.__dict__["role"] = role
            if type is None and not opts.urn:
                raise TypeError("Missing required property 'type'")
            __props__.__dict__["type"] = type
            __props__.__dict__["label"] = None
            __props__.__dict__["status"] = None
        super(OauthRoleAssignment, __self__).__init__(
            'okta:app/oauthRoleAssignment:OauthRoleAssignment',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            client_id: Optional[pulumi.Input[_builtins.str]] = None,
            label: Optional[pulumi.Input[_builtins.str]] = None,
            resource_set: Optional[pulumi.Input[_builtins.str]] = None,
            role: Optional[pulumi.Input[_builtins.str]] = None,
            status: Optional[pulumi.Input[_builtins.str]] = None,
            type: Optional[pulumi.Input[_builtins.str]] = None) -> 'OauthRoleAssignment':
        """
        Get an existing OauthRoleAssignment resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] client_id: Client ID for the role to be assigned to
        :param pulumi.Input[_builtins.str] label: Label of the role assignment
        :param pulumi.Input[_builtins.str] resource_set: Resource set for the custom role to assign, must be the ID of the created resource set.
        :param pulumi.Input[_builtins.str] role: Custom Role ID
        :param pulumi.Input[_builtins.str] status: Status of the role assignment
        :param pulumi.Input[_builtins.str] type: Role type to assign. This can be one of the standard Okta roles, such as `HELP_DESK_ADMIN`, or `CUSTOM`. Using custom requires the `resource_set` and `role` attributes to be set.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _OauthRoleAssignmentState.__new__(_OauthRoleAssignmentState)

        __props__.__dict__["client_id"] = client_id
        __props__.__dict__["label"] = label
        __props__.__dict__["resource_set"] = resource_set
        __props__.__dict__["role"] = role
        __props__.__dict__["status"] = status
        __props__.__dict__["type"] = type
        return OauthRoleAssignment(resource_name, opts=opts, __props__=__props__)

    @_builtins.property
    @pulumi.getter(name="clientId")
    def client_id(self) -> pulumi.Output[_builtins.str]:
        """
        Client ID for the role to be assigned to
        """
        return pulumi.get(self, "client_id")

    @_builtins.property
    @pulumi.getter
    def label(self) -> pulumi.Output[_builtins.str]:
        """
        Label of the role assignment
        """
        return pulumi.get(self, "label")

    @_builtins.property
    @pulumi.getter(name="resourceSet")
    def resource_set(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        Resource set for the custom role to assign, must be the ID of the created resource set.
        """
        return pulumi.get(self, "resource_set")

    @_builtins.property
    @pulumi.getter
    def role(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        Custom Role ID
        """
        return pulumi.get(self, "role")

    @_builtins.property
    @pulumi.getter
    def status(self) -> pulumi.Output[_builtins.str]:
        """
        Status of the role assignment
        """
        return pulumi.get(self, "status")

    @_builtins.property
    @pulumi.getter
    def type(self) -> pulumi.Output[_builtins.str]:
        """
        Role type to assign. This can be one of the standard Okta roles, such as `HELP_DESK_ADMIN`, or `CUSTOM`. Using custom requires the `resource_set` and `role` attributes to be set.
        """
        return pulumi.get(self, "type")




# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = [
    'RuleIdpDiscoveryAppExcludeArgs',
    'RuleIdpDiscoveryAppExcludeArgsDict',
    'RuleIdpDiscoveryAppIncludeArgs',
    'RuleIdpDiscoveryAppIncludeArgsDict',
    'RuleIdpDiscoveryIdpProviderArgs',
    'RuleIdpDiscoveryIdpProviderArgsDict',
    'RuleIdpDiscoveryPlatformIncludeArgs',
    'RuleIdpDiscoveryPlatformIncludeArgsDict',
    'RuleIdpDiscoveryUserIdentifierPatternArgs',
    'RuleIdpDiscoveryUserIdentifierPatternArgsDict',
    'RuleMfaAppExcludeArgs',
    'RuleMfaAppExcludeArgsDict',
    'RuleMfaAppIncludeArgs',
    'RuleMfaAppIncludeArgsDict',
    'RuleSignonFactorSequenceArgs',
    'RuleSignonFactorSequenceArgsDict',
    'RuleSignonFactorSequenceSecondaryCriteriaArgs',
    'RuleSignonFactorSequenceSecondaryCriteriaArgsDict',
]

MYPY = False

if not MYPY:
    class RuleIdpDiscoveryAppExcludeArgsDict(TypedDict):
        type: pulumi.Input[_builtins.str]
        id: NotRequired[pulumi.Input[_builtins.str]]
        name: NotRequired[pulumi.Input[_builtins.str]]
elif False:
    RuleIdpDiscoveryAppExcludeArgsDict: TypeAlias = Mapping[str, Any]

@pulumi.input_type
class RuleIdpDiscoveryAppExcludeArgs:
    def __init__(__self__, *,
                 type: pulumi.Input[_builtins.str],
                 id: Optional[pulumi.Input[_builtins.str]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None):
        pulumi.set(__self__, "type", type)
        if id is not None:
            pulumi.set(__self__, "id", id)
        if name is not None:
            pulumi.set(__self__, "name", name)

    @_builtins.property
    @pulumi.getter
    def type(self) -> pulumi.Input[_builtins.str]:
        return pulumi.get(self, "type")

    @type.setter
    def type(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "type", value)

    @_builtins.property
    @pulumi.getter
    def id(self) -> Optional[pulumi.Input[_builtins.str]]:
        return pulumi.get(self, "id")

    @id.setter
    def id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "id", value)

    @_builtins.property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[_builtins.str]]:
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "name", value)


if not MYPY:
    class RuleIdpDiscoveryAppIncludeArgsDict(TypedDict):
        type: pulumi.Input[_builtins.str]
        id: NotRequired[pulumi.Input[_builtins.str]]
        name: NotRequired[pulumi.Input[_builtins.str]]
elif False:
    RuleIdpDiscoveryAppIncludeArgsDict: TypeAlias = Mapping[str, Any]

@pulumi.input_type
class RuleIdpDiscoveryAppIncludeArgs:
    def __init__(__self__, *,
                 type: pulumi.Input[_builtins.str],
                 id: Optional[pulumi.Input[_builtins.str]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None):
        pulumi.set(__self__, "type", type)
        if id is not None:
            pulumi.set(__self__, "id", id)
        if name is not None:
            pulumi.set(__self__, "name", name)

    @_builtins.property
    @pulumi.getter
    def type(self) -> pulumi.Input[_builtins.str]:
        return pulumi.get(self, "type")

    @type.setter
    def type(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "type", value)

    @_builtins.property
    @pulumi.getter
    def id(self) -> Optional[pulumi.Input[_builtins.str]]:
        return pulumi.get(self, "id")

    @id.setter
    def id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "id", value)

    @_builtins.property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[_builtins.str]]:
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "name", value)


if not MYPY:
    class RuleIdpDiscoveryIdpProviderArgsDict(TypedDict):
        id: NotRequired[pulumi.Input[_builtins.str]]
        """
        The identifier for the Idp the rule should route to if all conditions are met.
        """
        type: NotRequired[pulumi.Input[_builtins.str]]
        """
        Type of IdP. One of: `AMAZON`, `APPLE`, `DISCORD`, `FACEBOOK`, `GITHUB`, `GITLAB`, `GOOGLE`, `IDV_CLEAR`, `IDV_INCODE`, `IDV_PERSONA`, `LINKEDIN`, `LOGINGOV`, `LOGINGOV_SANDBOX`, `MICROSOFT`, `OIDC`, `PAYPAL`, `PAYPAL_SANDBOX`, `SALESFORCE`, `SAML2`, `SPOTIFY`, `X509`, `XERO`, `YAHOO`, `YAHOOJP`, Default: `OKTA`
        """
elif False:
    RuleIdpDiscoveryIdpProviderArgsDict: TypeAlias = Mapping[str, Any]

@pulumi.input_type
class RuleIdpDiscoveryIdpProviderArgs:
    def __init__(__self__, *,
                 id: Optional[pulumi.Input[_builtins.str]] = None,
                 type: Optional[pulumi.Input[_builtins.str]] = None):
        """
        :param pulumi.Input[_builtins.str] id: The identifier for the Idp the rule should route to if all conditions are met.
        :param pulumi.Input[_builtins.str] type: Type of IdP. One of: `AMAZON`, `APPLE`, `DISCORD`, `FACEBOOK`, `GITHUB`, `GITLAB`, `GOOGLE`, `IDV_CLEAR`, `IDV_INCODE`, `IDV_PERSONA`, `LINKEDIN`, `LOGINGOV`, `LOGINGOV_SANDBOX`, `MICROSOFT`, `OIDC`, `PAYPAL`, `PAYPAL_SANDBOX`, `SALESFORCE`, `SAML2`, `SPOTIFY`, `X509`, `XERO`, `YAHOO`, `YAHOOJP`, Default: `OKTA`
        """
        if id is not None:
            pulumi.set(__self__, "id", id)
        if type is not None:
            pulumi.set(__self__, "type", type)

    @_builtins.property
    @pulumi.getter
    def id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The identifier for the Idp the rule should route to if all conditions are met.
        """
        return pulumi.get(self, "id")

    @id.setter
    def id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "id", value)

    @_builtins.property
    @pulumi.getter
    def type(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Type of IdP. One of: `AMAZON`, `APPLE`, `DISCORD`, `FACEBOOK`, `GITHUB`, `GITLAB`, `GOOGLE`, `IDV_CLEAR`, `IDV_INCODE`, `IDV_PERSONA`, `LINKEDIN`, `LOGINGOV`, `LOGINGOV_SANDBOX`, `MICROSOFT`, `OIDC`, `PAYPAL`, `PAYPAL_SANDBOX`, `SALESFORCE`, `SAML2`, `SPOTIFY`, `X509`, `XERO`, `YAHOO`, `YAHOOJP`, Default: `OKTA`
        """
        return pulumi.get(self, "type")

    @type.setter
    def type(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "type", value)


if not MYPY:
    class RuleIdpDiscoveryPlatformIncludeArgsDict(TypedDict):
        os_expression: NotRequired[pulumi.Input[_builtins.str]]
        """
        Only available with OTHER OS type
        """
        os_type: NotRequired[pulumi.Input[_builtins.str]]
        type: NotRequired[pulumi.Input[_builtins.str]]
elif False:
    RuleIdpDiscoveryPlatformIncludeArgsDict: TypeAlias = Mapping[str, Any]

@pulumi.input_type
class RuleIdpDiscoveryPlatformIncludeArgs:
    def __init__(__self__, *,
                 os_expression: Optional[pulumi.Input[_builtins.str]] = None,
                 os_type: Optional[pulumi.Input[_builtins.str]] = None,
                 type: Optional[pulumi.Input[_builtins.str]] = None):
        """
        :param pulumi.Input[_builtins.str] os_expression: Only available with OTHER OS type
        """
        if os_expression is not None:
            pulumi.set(__self__, "os_expression", os_expression)
        if os_type is not None:
            pulumi.set(__self__, "os_type", os_type)
        if type is not None:
            pulumi.set(__self__, "type", type)

    @_builtins.property
    @pulumi.getter(name="osExpression")
    def os_expression(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Only available with OTHER OS type
        """
        return pulumi.get(self, "os_expression")

    @os_expression.setter
    def os_expression(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "os_expression", value)

    @_builtins.property
    @pulumi.getter(name="osType")
    def os_type(self) -> Optional[pulumi.Input[_builtins.str]]:
        return pulumi.get(self, "os_type")

    @os_type.setter
    def os_type(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "os_type", value)

    @_builtins.property
    @pulumi.getter
    def type(self) -> Optional[pulumi.Input[_builtins.str]]:
        return pulumi.get(self, "type")

    @type.setter
    def type(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "type", value)


if not MYPY:
    class RuleIdpDiscoveryUserIdentifierPatternArgsDict(TypedDict):
        match_type: NotRequired[pulumi.Input[_builtins.str]]
        value: NotRequired[pulumi.Input[_builtins.str]]
elif False:
    RuleIdpDiscoveryUserIdentifierPatternArgsDict: TypeAlias = Mapping[str, Any]

@pulumi.input_type
class RuleIdpDiscoveryUserIdentifierPatternArgs:
    def __init__(__self__, *,
                 match_type: Optional[pulumi.Input[_builtins.str]] = None,
                 value: Optional[pulumi.Input[_builtins.str]] = None):
        if match_type is not None:
            pulumi.set(__self__, "match_type", match_type)
        if value is not None:
            pulumi.set(__self__, "value", value)

    @_builtins.property
    @pulumi.getter(name="matchType")
    def match_type(self) -> Optional[pulumi.Input[_builtins.str]]:
        return pulumi.get(self, "match_type")

    @match_type.setter
    def match_type(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "match_type", value)

    @_builtins.property
    @pulumi.getter
    def value(self) -> Optional[pulumi.Input[_builtins.str]]:
        return pulumi.get(self, "value")

    @value.setter
    def value(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "value", value)


if not MYPY:
    class RuleMfaAppExcludeArgsDict(TypedDict):
        type: pulumi.Input[_builtins.str]
        id: NotRequired[pulumi.Input[_builtins.str]]
        name: NotRequired[pulumi.Input[_builtins.str]]
elif False:
    RuleMfaAppExcludeArgsDict: TypeAlias = Mapping[str, Any]

@pulumi.input_type
class RuleMfaAppExcludeArgs:
    def __init__(__self__, *,
                 type: pulumi.Input[_builtins.str],
                 id: Optional[pulumi.Input[_builtins.str]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None):
        pulumi.set(__self__, "type", type)
        if id is not None:
            pulumi.set(__self__, "id", id)
        if name is not None:
            pulumi.set(__self__, "name", name)

    @_builtins.property
    @pulumi.getter
    def type(self) -> pulumi.Input[_builtins.str]:
        return pulumi.get(self, "type")

    @type.setter
    def type(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "type", value)

    @_builtins.property
    @pulumi.getter
    def id(self) -> Optional[pulumi.Input[_builtins.str]]:
        return pulumi.get(self, "id")

    @id.setter
    def id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "id", value)

    @_builtins.property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[_builtins.str]]:
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "name", value)


if not MYPY:
    class RuleMfaAppIncludeArgsDict(TypedDict):
        type: pulumi.Input[_builtins.str]
        id: NotRequired[pulumi.Input[_builtins.str]]
        name: NotRequired[pulumi.Input[_builtins.str]]
elif False:
    RuleMfaAppIncludeArgsDict: TypeAlias = Mapping[str, Any]

@pulumi.input_type
class RuleMfaAppIncludeArgs:
    def __init__(__self__, *,
                 type: pulumi.Input[_builtins.str],
                 id: Optional[pulumi.Input[_builtins.str]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None):
        pulumi.set(__self__, "type", type)
        if id is not None:
            pulumi.set(__self__, "id", id)
        if name is not None:
            pulumi.set(__self__, "name", name)

    @_builtins.property
    @pulumi.getter
    def type(self) -> pulumi.Input[_builtins.str]:
        return pulumi.get(self, "type")

    @type.setter
    def type(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "type", value)

    @_builtins.property
    @pulumi.getter
    def id(self) -> Optional[pulumi.Input[_builtins.str]]:
        return pulumi.get(self, "id")

    @id.setter
    def id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "id", value)

    @_builtins.property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[_builtins.str]]:
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "name", value)


if not MYPY:
    class RuleSignonFactorSequenceArgsDict(TypedDict):
        primary_criteria_factor_type: pulumi.Input[_builtins.str]
        """
        Type of a Factor
        """
        primary_criteria_provider: pulumi.Input[_builtins.str]
        """
        Factor provider
        """
        secondary_criterias: NotRequired[pulumi.Input[Sequence[pulumi.Input['RuleSignonFactorSequenceSecondaryCriteriaArgsDict']]]]
elif False:
    RuleSignonFactorSequenceArgsDict: TypeAlias = Mapping[str, Any]

@pulumi.input_type
class RuleSignonFactorSequenceArgs:
    def __init__(__self__, *,
                 primary_criteria_factor_type: pulumi.Input[_builtins.str],
                 primary_criteria_provider: pulumi.Input[_builtins.str],
                 secondary_criterias: Optional[pulumi.Input[Sequence[pulumi.Input['RuleSignonFactorSequenceSecondaryCriteriaArgs']]]] = None):
        """
        :param pulumi.Input[_builtins.str] primary_criteria_factor_type: Type of a Factor
        :param pulumi.Input[_builtins.str] primary_criteria_provider: Factor provider
        """
        pulumi.set(__self__, "primary_criteria_factor_type", primary_criteria_factor_type)
        pulumi.set(__self__, "primary_criteria_provider", primary_criteria_provider)
        if secondary_criterias is not None:
            pulumi.set(__self__, "secondary_criterias", secondary_criterias)

    @_builtins.property
    @pulumi.getter(name="primaryCriteriaFactorType")
    def primary_criteria_factor_type(self) -> pulumi.Input[_builtins.str]:
        """
        Type of a Factor
        """
        return pulumi.get(self, "primary_criteria_factor_type")

    @primary_criteria_factor_type.setter
    def primary_criteria_factor_type(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "primary_criteria_factor_type", value)

    @_builtins.property
    @pulumi.getter(name="primaryCriteriaProvider")
    def primary_criteria_provider(self) -> pulumi.Input[_builtins.str]:
        """
        Factor provider
        """
        return pulumi.get(self, "primary_criteria_provider")

    @primary_criteria_provider.setter
    def primary_criteria_provider(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "primary_criteria_provider", value)

    @_builtins.property
    @pulumi.getter(name="secondaryCriterias")
    def secondary_criterias(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['RuleSignonFactorSequenceSecondaryCriteriaArgs']]]]:
        return pulumi.get(self, "secondary_criterias")

    @secondary_criterias.setter
    def secondary_criterias(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['RuleSignonFactorSequenceSecondaryCriteriaArgs']]]]):
        pulumi.set(self, "secondary_criterias", value)


if not MYPY:
    class RuleSignonFactorSequenceSecondaryCriteriaArgsDict(TypedDict):
        factor_type: pulumi.Input[_builtins.str]
        """
        Type of a Factor
        """
        provider: pulumi.Input[_builtins.str]
        """
        Factor provider
        """
elif False:
    RuleSignonFactorSequenceSecondaryCriteriaArgsDict: TypeAlias = Mapping[str, Any]

@pulumi.input_type
class RuleSignonFactorSequenceSecondaryCriteriaArgs:
    def __init__(__self__, *,
                 factor_type: pulumi.Input[_builtins.str],
                 provider: pulumi.Input[_builtins.str]):
        """
        :param pulumi.Input[_builtins.str] factor_type: Type of a Factor
        :param pulumi.Input[_builtins.str] provider: Factor provider
        """
        pulumi.set(__self__, "factor_type", factor_type)
        pulumi.set(__self__, "provider", provider)

    @_builtins.property
    @pulumi.getter(name="factorType")
    def factor_type(self) -> pulumi.Input[_builtins.str]:
        """
        Type of a Factor
        """
        return pulumi.get(self, "factor_type")

    @factor_type.setter
    def factor_type(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "factor_type", value)

    @_builtins.property
    @pulumi.getter
    def provider(self) -> pulumi.Input[_builtins.str]:
        """
        Factor provider
        """
        return pulumi.get(self, "provider")

    @provider.setter
    def provider(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "provider", value)





# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities

__all__ = ['LinkValueArgs', 'LinkValue']

@pulumi.input_type
class LinkValueArgs:
    def __init__(__self__, *,
                 primary_name: pulumi.Input[_builtins.str],
                 primary_user_id: pulumi.Input[_builtins.str],
                 associated_user_ids: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None):
        """
        The set of arguments for constructing a LinkValue resource.
        :param pulumi.Input[_builtins.str] primary_name: Name of the `primary` relationship being assigned.
        :param pulumi.Input[_builtins.str] primary_user_id: User ID to be assigned to `primary` for the 'associated' user in the specified relationship.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] associated_user_ids: Set of User IDs or login values of the users to be assigned the `associated` relationship.
        """
        pulumi.set(__self__, "primary_name", primary_name)
        pulumi.set(__self__, "primary_user_id", primary_user_id)
        if associated_user_ids is not None:
            pulumi.set(__self__, "associated_user_ids", associated_user_ids)

    @_builtins.property
    @pulumi.getter(name="primaryName")
    def primary_name(self) -> pulumi.Input[_builtins.str]:
        """
        Name of the `primary` relationship being assigned.
        """
        return pulumi.get(self, "primary_name")

    @primary_name.setter
    def primary_name(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "primary_name", value)

    @_builtins.property
    @pulumi.getter(name="primaryUserId")
    def primary_user_id(self) -> pulumi.Input[_builtins.str]:
        """
        User ID to be assigned to `primary` for the 'associated' user in the specified relationship.
        """
        return pulumi.get(self, "primary_user_id")

    @primary_user_id.setter
    def primary_user_id(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "primary_user_id", value)

    @_builtins.property
    @pulumi.getter(name="associatedUserIds")
    def associated_user_ids(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]:
        """
        Set of User IDs or login values of the users to be assigned the `associated` relationship.
        """
        return pulumi.get(self, "associated_user_ids")

    @associated_user_ids.setter
    def associated_user_ids(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]):
        pulumi.set(self, "associated_user_ids", value)


@pulumi.input_type
class _LinkValueState:
    def __init__(__self__, *,
                 associated_user_ids: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 primary_name: Optional[pulumi.Input[_builtins.str]] = None,
                 primary_user_id: Optional[pulumi.Input[_builtins.str]] = None):
        """
        Input properties used for looking up and filtering LinkValue resources.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] associated_user_ids: Set of User IDs or login values of the users to be assigned the `associated` relationship.
        :param pulumi.Input[_builtins.str] primary_name: Name of the `primary` relationship being assigned.
        :param pulumi.Input[_builtins.str] primary_user_id: User ID to be assigned to `primary` for the 'associated' user in the specified relationship.
        """
        if associated_user_ids is not None:
            pulumi.set(__self__, "associated_user_ids", associated_user_ids)
        if primary_name is not None:
            pulumi.set(__self__, "primary_name", primary_name)
        if primary_user_id is not None:
            pulumi.set(__self__, "primary_user_id", primary_user_id)

    @_builtins.property
    @pulumi.getter(name="associatedUserIds")
    def associated_user_ids(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]:
        """
        Set of User IDs or login values of the users to be assigned the `associated` relationship.
        """
        return pulumi.get(self, "associated_user_ids")

    @associated_user_ids.setter
    def associated_user_ids(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]):
        pulumi.set(self, "associated_user_ids", value)

    @_builtins.property
    @pulumi.getter(name="primaryName")
    def primary_name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Name of the `primary` relationship being assigned.
        """
        return pulumi.get(self, "primary_name")

    @primary_name.setter
    def primary_name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "primary_name", value)

    @_builtins.property
    @pulumi.getter(name="primaryUserId")
    def primary_user_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        User ID to be assigned to `primary` for the 'associated' user in the specified relationship.
        """
        return pulumi.get(self, "primary_user_id")

    @primary_user_id.setter
    def primary_user_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "primary_user_id", value)


@pulumi.type_token("okta:index/linkValue:LinkValue")
class LinkValue(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 associated_user_ids: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 primary_name: Optional[pulumi.Input[_builtins.str]] = None,
                 primary_user_id: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        """
        Manages users relationships. Link value operations allow you to create relationships between primary and associated users.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_okta as okta

        padishah = okta.LinkDefinition("padishah",
            primary_name="emperor",
            primary_title="Emperor",
            primary_description="Hereditary ruler of the Imperium and the Known Universe",
            associated_name="sardaukar",
            associated_title="Sardaukar",
            associated_description="Elite military force member")
        emperor = okta.user.User("emperor",
            first_name="Shaddam",
            last_name="Corrino IV",
            login="shaddam.corrino.iv@salusa-secundus.planet",
            email="shaddam.corrino.iv@salusa-secundus.planet")
        sardaukars = []
        for range in [{"value": i} for i in range(0, 5)]:
            sardaukars.append(okta.user.User(f"sardaukars-{range['value']}",
                first_name="Amrit",
                last_name=f"Sardaukar_{range['value']}",
                login=f"amritsardaukar_{range['value']}@salusa-secundus.planet",
                email=f"amritsardaukar_{range['value']}@salusa-secundus.planet"))
        example = okta.LinkValue("example",
            primary_name=padishah.primary_name,
            primary_user_id=emperor.id,
            associated_user_ids=[
                sardaukars[0].id,
                sardaukars[1].id,
                sardaukars[2].id,
                sardaukars[3].id,
                sardaukars[4].id,
            ])
        ```

        ## Import

        ```sh
        $ pulumi import okta:index/linkValue:LinkValue example <primary_name>/<primary_user_id>
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] associated_user_ids: Set of User IDs or login values of the users to be assigned the `associated` relationship.
        :param pulumi.Input[_builtins.str] primary_name: Name of the `primary` relationship being assigned.
        :param pulumi.Input[_builtins.str] primary_user_id: User ID to be assigned to `primary` for the 'associated' user in the specified relationship.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: LinkValueArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Manages users relationships. Link value operations allow you to create relationships between primary and associated users.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_okta as okta

        padishah = okta.LinkDefinition("padishah",
            primary_name="emperor",
            primary_title="Emperor",
            primary_description="Hereditary ruler of the Imperium and the Known Universe",
            associated_name="sardaukar",
            associated_title="Sardaukar",
            associated_description="Elite military force member")
        emperor = okta.user.User("emperor",
            first_name="Shaddam",
            last_name="Corrino IV",
            login="shaddam.corrino.iv@salusa-secundus.planet",
            email="shaddam.corrino.iv@salusa-secundus.planet")
        sardaukars = []
        for range in [{"value": i} for i in range(0, 5)]:
            sardaukars.append(okta.user.User(f"sardaukars-{range['value']}",
                first_name="Amrit",
                last_name=f"Sardaukar_{range['value']}",
                login=f"amritsardaukar_{range['value']}@salusa-secundus.planet",
                email=f"amritsardaukar_{range['value']}@salusa-secundus.planet"))
        example = okta.LinkValue("example",
            primary_name=padishah.primary_name,
            primary_user_id=emperor.id,
            associated_user_ids=[
                sardaukars[0].id,
                sardaukars[1].id,
                sardaukars[2].id,
                sardaukars[3].id,
                sardaukars[4].id,
            ])
        ```

        ## Import

        ```sh
        $ pulumi import okta:index/linkValue:LinkValue example <primary_name>/<primary_user_id>
        ```

        :param str resource_name: The name of the resource.
        :param LinkValueArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(LinkValueArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 associated_user_ids: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 primary_name: Optional[pulumi.Input[_builtins.str]] = None,
                 primary_user_id: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = LinkValueArgs.__new__(LinkValueArgs)

            __props__.__dict__["associated_user_ids"] = associated_user_ids
            if primary_name is None and not opts.urn:
                raise TypeError("Missing required property 'primary_name'")
            __props__.__dict__["primary_name"] = primary_name
            if primary_user_id is None and not opts.urn:
                raise TypeError("Missing required property 'primary_user_id'")
            __props__.__dict__["primary_user_id"] = primary_user_id
        super(LinkValue, __self__).__init__(
            'okta:index/linkValue:LinkValue',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            associated_user_ids: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
            primary_name: Optional[pulumi.Input[_builtins.str]] = None,
            primary_user_id: Optional[pulumi.Input[_builtins.str]] = None) -> 'LinkValue':
        """
        Get an existing LinkValue resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] associated_user_ids: Set of User IDs or login values of the users to be assigned the `associated` relationship.
        :param pulumi.Input[_builtins.str] primary_name: Name of the `primary` relationship being assigned.
        :param pulumi.Input[_builtins.str] primary_user_id: User ID to be assigned to `primary` for the 'associated' user in the specified relationship.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _LinkValueState.__new__(_LinkValueState)

        __props__.__dict__["associated_user_ids"] = associated_user_ids
        __props__.__dict__["primary_name"] = primary_name
        __props__.__dict__["primary_user_id"] = primary_user_id
        return LinkValue(resource_name, opts=opts, __props__=__props__)

    @_builtins.property
    @pulumi.getter(name="associatedUserIds")
    def associated_user_ids(self) -> pulumi.Output[Optional[Sequence[_builtins.str]]]:
        """
        Set of User IDs or login values of the users to be assigned the `associated` relationship.
        """
        return pulumi.get(self, "associated_user_ids")

    @_builtins.property
    @pulumi.getter(name="primaryName")
    def primary_name(self) -> pulumi.Output[_builtins.str]:
        """
        Name of the `primary` relationship being assigned.
        """
        return pulumi.get(self, "primary_name")

    @_builtins.property
    @pulumi.getter(name="primaryUserId")
    def primary_user_id(self) -> pulumi.Output[_builtins.str]:
        """
        User ID to be assigned to `primary` for the 'associated' user in the specified relationship.
        """
        return pulumi.get(self, "primary_user_id")




# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs
from ._inputs import *

__all__ = ['RuleSignonArgs', 'RuleSignon']

@pulumi.input_type
class RuleSignonArgs:
    def __init__(__self__, *,
                 access: Optional[pulumi.Input[_builtins.str]] = None,
                 authtype: Optional[pulumi.Input[_builtins.str]] = None,
                 behaviors: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 factor_sequences: Optional[pulumi.Input[Sequence[pulumi.Input['RuleSignonFactorSequenceArgs']]]] = None,
                 identity_provider: Optional[pulumi.Input[_builtins.str]] = None,
                 identity_provider_ids: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 mfa_lifetime: Optional[pulumi.Input[_builtins.int]] = None,
                 mfa_prompt: Optional[pulumi.Input[_builtins.str]] = None,
                 mfa_remember_device: Optional[pulumi.Input[_builtins.bool]] = None,
                 mfa_required: Optional[pulumi.Input[_builtins.bool]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 network_connection: Optional[pulumi.Input[_builtins.str]] = None,
                 network_excludes: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 network_includes: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 policy_id: Optional[pulumi.Input[_builtins.str]] = None,
                 primary_factor: Optional[pulumi.Input[_builtins.str]] = None,
                 priority: Optional[pulumi.Input[_builtins.int]] = None,
                 risc_level: Optional[pulumi.Input[_builtins.str]] = None,
                 risk_level: Optional[pulumi.Input[_builtins.str]] = None,
                 session_idle: Optional[pulumi.Input[_builtins.int]] = None,
                 session_lifetime: Optional[pulumi.Input[_builtins.int]] = None,
                 session_persistent: Optional[pulumi.Input[_builtins.bool]] = None,
                 status: Optional[pulumi.Input[_builtins.str]] = None,
                 users_excludeds: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None):
        """
        The set of arguments for constructing a RuleSignon resource.
        :param pulumi.Input[_builtins.str] access: Allow or deny access based on the rule conditions: `ALLOW`, `DENY` or `CHALLENGE`. Default: `ALLOW`
        :param pulumi.Input[_builtins.str] authtype: Authentication entrypoint: `ANY`, `RADIUS` or `LDAP_INTERFACE`. Default: `ANY`
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] behaviors: List of behavior IDs
        :param pulumi.Input[Sequence[pulumi.Input['RuleSignonFactorSequenceArgs']]] factor_sequences: Auth factor sequences. Should be set if 'access = "CHALLENGE"'.
               	- 'primary_criteria_provider' - (Required) Primary provider of the auth section.
               	- 'primary_criteria_factor_type' - (Required) Primary factor type of the auth section.
               	- 'secondary_criteria' - (Optional) Additional authentication steps.
               	- 'provider' - (Required) Provider of the additional authentication step.
               	- 'factor_type' - (Required) Factor type of the additional authentication step.
        :param pulumi.Input[_builtins.str] identity_provider: Apply rule based on the IdP used: `ANY`, `OKTA` or `SPECIFIC_IDP`. Default: `ANY`. > **WARNING**: Use of `identity_provider` requires a feature flag to be enabled.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] identity_provider_ids: When identity_provider is `SPECIFIC_IDP` then this is the list of IdP IDs to apply the rule on
        :param pulumi.Input[_builtins.int] mfa_lifetime: Elapsed time before the next MFA challenge
        :param pulumi.Input[_builtins.str] mfa_prompt: Prompt for MFA based on the device used, a factor session lifetime, or every sign-on attempt: `DEVICE`, `SESSION` or`ALWAYS`.
        :param pulumi.Input[_builtins.bool] mfa_remember_device: Remember MFA device. Default: `false`
        :param pulumi.Input[_builtins.bool] mfa_required: Require MFA. Default: `false`
        :param pulumi.Input[_builtins.str] name: Policy Rule Name
        :param pulumi.Input[_builtins.str] network_connection: Network selection mode: `ANYWHERE`, `ZONE`, `ON_NETWORK`, or `OFF_NETWORK`. Default: `ANYWHERE`
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] network_excludes: Required if `network_connection` = `ZONE`. Indicates the network zones to exclude.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] network_includes: Required if `network_connection` = `ZONE`. Indicates the network zones to include.
        :param pulumi.Input[_builtins.str] policy_id: Policy ID of the Rule
        :param pulumi.Input[_builtins.str] primary_factor: Rule's primary factor. **WARNING** Ony works as a part of the Identity Engine. Valid values: `PASSWORD_IDP_ANY_FACTOR`, `PASSWORD_IDP`.
        :param pulumi.Input[_builtins.int] priority: Rule priority. This attribute can be set to a valid priority. To avoid an endless diff situation an error is thrown if an invalid property is provided. The Okta API defaults to the last (lowest) if not provided.
        :param pulumi.Input[_builtins.str] risc_level: Risc level: ANY, LOW, MEDIUM or HIGH. Default: `ANY`
        :param pulumi.Input[_builtins.str] risk_level: Risk level: ANY, LOW, MEDIUM or HIGH. Default: `ANY`
        :param pulumi.Input[_builtins.int] session_idle: Max minutes a session can be idle. Default: `120`
        :param pulumi.Input[_builtins.int] session_lifetime: Max minutes a session is active: Disable = 0. Default: `120`
        :param pulumi.Input[_builtins.bool] session_persistent: Whether session cookies will last across browser sessions. Okta Administrators can never have persistent session cookies. Default: `false`
        :param pulumi.Input[_builtins.str] status: Policy Rule Status: `ACTIVE` or `INACTIVE`. Default: `ACTIVE`
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] users_excludeds: Set of User IDs to Exclude
        """
        if access is not None:
            pulumi.set(__self__, "access", access)
        if authtype is not None:
            pulumi.set(__self__, "authtype", authtype)
        if behaviors is not None:
            pulumi.set(__self__, "behaviors", behaviors)
        if factor_sequences is not None:
            pulumi.set(__self__, "factor_sequences", factor_sequences)
        if identity_provider is not None:
            pulumi.set(__self__, "identity_provider", identity_provider)
        if identity_provider_ids is not None:
            pulumi.set(__self__, "identity_provider_ids", identity_provider_ids)
        if mfa_lifetime is not None:
            pulumi.set(__self__, "mfa_lifetime", mfa_lifetime)
        if mfa_prompt is not None:
            pulumi.set(__self__, "mfa_prompt", mfa_prompt)
        if mfa_remember_device is not None:
            pulumi.set(__self__, "mfa_remember_device", mfa_remember_device)
        if mfa_required is not None:
            pulumi.set(__self__, "mfa_required", mfa_required)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if network_connection is not None:
            pulumi.set(__self__, "network_connection", network_connection)
        if network_excludes is not None:
            pulumi.set(__self__, "network_excludes", network_excludes)
        if network_includes is not None:
            pulumi.set(__self__, "network_includes", network_includes)
        if policy_id is not None:
            pulumi.set(__self__, "policy_id", policy_id)
        if primary_factor is not None:
            pulumi.set(__self__, "primary_factor", primary_factor)
        if priority is not None:
            pulumi.set(__self__, "priority", priority)
        if risc_level is not None:
            warnings.warn("""Attribute typo, switch to risk_level instead. Default: `ANY`""", DeprecationWarning)
            pulumi.log.warn("""risc_level is deprecated: Attribute typo, switch to risk_level instead. Default: `ANY`""")
        if risc_level is not None:
            pulumi.set(__self__, "risc_level", risc_level)
        if risk_level is not None:
            pulumi.set(__self__, "risk_level", risk_level)
        if session_idle is not None:
            pulumi.set(__self__, "session_idle", session_idle)
        if session_lifetime is not None:
            pulumi.set(__self__, "session_lifetime", session_lifetime)
        if session_persistent is not None:
            pulumi.set(__self__, "session_persistent", session_persistent)
        if status is not None:
            pulumi.set(__self__, "status", status)
        if users_excludeds is not None:
            pulumi.set(__self__, "users_excludeds", users_excludeds)

    @_builtins.property
    @pulumi.getter
    def access(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Allow or deny access based on the rule conditions: `ALLOW`, `DENY` or `CHALLENGE`. Default: `ALLOW`
        """
        return pulumi.get(self, "access")

    @access.setter
    def access(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "access", value)

    @_builtins.property
    @pulumi.getter
    def authtype(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Authentication entrypoint: `ANY`, `RADIUS` or `LDAP_INTERFACE`. Default: `ANY`
        """
        return pulumi.get(self, "authtype")

    @authtype.setter
    def authtype(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "authtype", value)

    @_builtins.property
    @pulumi.getter
    def behaviors(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]:
        """
        List of behavior IDs
        """
        return pulumi.get(self, "behaviors")

    @behaviors.setter
    def behaviors(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]):
        pulumi.set(self, "behaviors", value)

    @_builtins.property
    @pulumi.getter(name="factorSequences")
    def factor_sequences(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['RuleSignonFactorSequenceArgs']]]]:
        """
        Auth factor sequences. Should be set if 'access = "CHALLENGE"'.
        	- 'primary_criteria_provider' - (Required) Primary provider of the auth section.
        	- 'primary_criteria_factor_type' - (Required) Primary factor type of the auth section.
        	- 'secondary_criteria' - (Optional) Additional authentication steps.
        	- 'provider' - (Required) Provider of the additional authentication step.
        	- 'factor_type' - (Required) Factor type of the additional authentication step.
        """
        return pulumi.get(self, "factor_sequences")

    @factor_sequences.setter
    def factor_sequences(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['RuleSignonFactorSequenceArgs']]]]):
        pulumi.set(self, "factor_sequences", value)

    @_builtins.property
    @pulumi.getter(name="identityProvider")
    def identity_provider(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Apply rule based on the IdP used: `ANY`, `OKTA` or `SPECIFIC_IDP`. Default: `ANY`. > **WARNING**: Use of `identity_provider` requires a feature flag to be enabled.
        """
        return pulumi.get(self, "identity_provider")

    @identity_provider.setter
    def identity_provider(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "identity_provider", value)

    @_builtins.property
    @pulumi.getter(name="identityProviderIds")
    def identity_provider_ids(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]:
        """
        When identity_provider is `SPECIFIC_IDP` then this is the list of IdP IDs to apply the rule on
        """
        return pulumi.get(self, "identity_provider_ids")

    @identity_provider_ids.setter
    def identity_provider_ids(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]):
        pulumi.set(self, "identity_provider_ids", value)

    @_builtins.property
    @pulumi.getter(name="mfaLifetime")
    def mfa_lifetime(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        Elapsed time before the next MFA challenge
        """
        return pulumi.get(self, "mfa_lifetime")

    @mfa_lifetime.setter
    def mfa_lifetime(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "mfa_lifetime", value)

    @_builtins.property
    @pulumi.getter(name="mfaPrompt")
    def mfa_prompt(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Prompt for MFA based on the device used, a factor session lifetime, or every sign-on attempt: `DEVICE`, `SESSION` or`ALWAYS`.
        """
        return pulumi.get(self, "mfa_prompt")

    @mfa_prompt.setter
    def mfa_prompt(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "mfa_prompt", value)

    @_builtins.property
    @pulumi.getter(name="mfaRememberDevice")
    def mfa_remember_device(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Remember MFA device. Default: `false`
        """
        return pulumi.get(self, "mfa_remember_device")

    @mfa_remember_device.setter
    def mfa_remember_device(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "mfa_remember_device", value)

    @_builtins.property
    @pulumi.getter(name="mfaRequired")
    def mfa_required(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Require MFA. Default: `false`
        """
        return pulumi.get(self, "mfa_required")

    @mfa_required.setter
    def mfa_required(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "mfa_required", value)

    @_builtins.property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Policy Rule Name
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "name", value)

    @_builtins.property
    @pulumi.getter(name="networkConnection")
    def network_connection(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Network selection mode: `ANYWHERE`, `ZONE`, `ON_NETWORK`, or `OFF_NETWORK`. Default: `ANYWHERE`
        """
        return pulumi.get(self, "network_connection")

    @network_connection.setter
    def network_connection(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "network_connection", value)

    @_builtins.property
    @pulumi.getter(name="networkExcludes")
    def network_excludes(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]:
        """
        Required if `network_connection` = `ZONE`. Indicates the network zones to exclude.
        """
        return pulumi.get(self, "network_excludes")

    @network_excludes.setter
    def network_excludes(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]):
        pulumi.set(self, "network_excludes", value)

    @_builtins.property
    @pulumi.getter(name="networkIncludes")
    def network_includes(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]:
        """
        Required if `network_connection` = `ZONE`. Indicates the network zones to include.
        """
        return pulumi.get(self, "network_includes")

    @network_includes.setter
    def network_includes(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]):
        pulumi.set(self, "network_includes", value)

    @_builtins.property
    @pulumi.getter(name="policyId")
    def policy_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Policy ID of the Rule
        """
        return pulumi.get(self, "policy_id")

    @policy_id.setter
    def policy_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "policy_id", value)

    @_builtins.property
    @pulumi.getter(name="primaryFactor")
    def primary_factor(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Rule's primary factor. **WARNING** Ony works as a part of the Identity Engine. Valid values: `PASSWORD_IDP_ANY_FACTOR`, `PASSWORD_IDP`.
        """
        return pulumi.get(self, "primary_factor")

    @primary_factor.setter
    def primary_factor(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "primary_factor", value)

    @_builtins.property
    @pulumi.getter
    def priority(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        Rule priority. This attribute can be set to a valid priority. To avoid an endless diff situation an error is thrown if an invalid property is provided. The Okta API defaults to the last (lowest) if not provided.
        """
        return pulumi.get(self, "priority")

    @priority.setter
    def priority(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "priority", value)

    @_builtins.property
    @pulumi.getter(name="riscLevel")
    @_utilities.deprecated("""Attribute typo, switch to risk_level instead. Default: `ANY`""")
    def risc_level(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Risc level: ANY, LOW, MEDIUM or HIGH. Default: `ANY`
        """
        return pulumi.get(self, "risc_level")

    @risc_level.setter
    def risc_level(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "risc_level", value)

    @_builtins.property
    @pulumi.getter(name="riskLevel")
    def risk_level(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Risk level: ANY, LOW, MEDIUM or HIGH. Default: `ANY`
        """
        return pulumi.get(self, "risk_level")

    @risk_level.setter
    def risk_level(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "risk_level", value)

    @_builtins.property
    @pulumi.getter(name="sessionIdle")
    def session_idle(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        Max minutes a session can be idle. Default: `120`
        """
        return pulumi.get(self, "session_idle")

    @session_idle.setter
    def session_idle(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "session_idle", value)

    @_builtins.property
    @pulumi.getter(name="sessionLifetime")
    def session_lifetime(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        Max minutes a session is active: Disable = 0. Default: `120`
        """
        return pulumi.get(self, "session_lifetime")

    @session_lifetime.setter
    def session_lifetime(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "session_lifetime", value)

    @_builtins.property
    @pulumi.getter(name="sessionPersistent")
    def session_persistent(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Whether session cookies will last across browser sessions. Okta Administrators can never have persistent session cookies. Default: `false`
        """
        return pulumi.get(self, "session_persistent")

    @session_persistent.setter
    def session_persistent(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "session_persistent", value)

    @_builtins.property
    @pulumi.getter
    def status(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Policy Rule Status: `ACTIVE` or `INACTIVE`. Default: `ACTIVE`
        """
        return pulumi.get(self, "status")

    @status.setter
    def status(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "status", value)

    @_builtins.property
    @pulumi.getter(name="usersExcludeds")
    def users_excludeds(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]:
        """
        Set of User IDs to Exclude
        """
        return pulumi.get(self, "users_excludeds")

    @users_excludeds.setter
    def users_excludeds(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]):
        pulumi.set(self, "users_excludeds", value)


@pulumi.input_type
class _RuleSignonState:
    def __init__(__self__, *,
                 access: Optional[pulumi.Input[_builtins.str]] = None,
                 authtype: Optional[pulumi.Input[_builtins.str]] = None,
                 behaviors: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 factor_sequences: Optional[pulumi.Input[Sequence[pulumi.Input['RuleSignonFactorSequenceArgs']]]] = None,
                 identity_provider: Optional[pulumi.Input[_builtins.str]] = None,
                 identity_provider_ids: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 mfa_lifetime: Optional[pulumi.Input[_builtins.int]] = None,
                 mfa_prompt: Optional[pulumi.Input[_builtins.str]] = None,
                 mfa_remember_device: Optional[pulumi.Input[_builtins.bool]] = None,
                 mfa_required: Optional[pulumi.Input[_builtins.bool]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 network_connection: Optional[pulumi.Input[_builtins.str]] = None,
                 network_excludes: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 network_includes: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 policy_id: Optional[pulumi.Input[_builtins.str]] = None,
                 primary_factor: Optional[pulumi.Input[_builtins.str]] = None,
                 priority: Optional[pulumi.Input[_builtins.int]] = None,
                 risc_level: Optional[pulumi.Input[_builtins.str]] = None,
                 risk_level: Optional[pulumi.Input[_builtins.str]] = None,
                 session_idle: Optional[pulumi.Input[_builtins.int]] = None,
                 session_lifetime: Optional[pulumi.Input[_builtins.int]] = None,
                 session_persistent: Optional[pulumi.Input[_builtins.bool]] = None,
                 status: Optional[pulumi.Input[_builtins.str]] = None,
                 users_excludeds: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None):
        """
        Input properties used for looking up and filtering RuleSignon resources.
        :param pulumi.Input[_builtins.str] access: Allow or deny access based on the rule conditions: `ALLOW`, `DENY` or `CHALLENGE`. Default: `ALLOW`
        :param pulumi.Input[_builtins.str] authtype: Authentication entrypoint: `ANY`, `RADIUS` or `LDAP_INTERFACE`. Default: `ANY`
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] behaviors: List of behavior IDs
        :param pulumi.Input[Sequence[pulumi.Input['RuleSignonFactorSequenceArgs']]] factor_sequences: Auth factor sequences. Should be set if 'access = "CHALLENGE"'.
               	- 'primary_criteria_provider' - (Required) Primary provider of the auth section.
               	- 'primary_criteria_factor_type' - (Required) Primary factor type of the auth section.
               	- 'secondary_criteria' - (Optional) Additional authentication steps.
               	- 'provider' - (Required) Provider of the additional authentication step.
               	- 'factor_type' - (Required) Factor type of the additional authentication step.
        :param pulumi.Input[_builtins.str] identity_provider: Apply rule based on the IdP used: `ANY`, `OKTA` or `SPECIFIC_IDP`. Default: `ANY`. > **WARNING**: Use of `identity_provider` requires a feature flag to be enabled.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] identity_provider_ids: When identity_provider is `SPECIFIC_IDP` then this is the list of IdP IDs to apply the rule on
        :param pulumi.Input[_builtins.int] mfa_lifetime: Elapsed time before the next MFA challenge
        :param pulumi.Input[_builtins.str] mfa_prompt: Prompt for MFA based on the device used, a factor session lifetime, or every sign-on attempt: `DEVICE`, `SESSION` or`ALWAYS`.
        :param pulumi.Input[_builtins.bool] mfa_remember_device: Remember MFA device. Default: `false`
        :param pulumi.Input[_builtins.bool] mfa_required: Require MFA. Default: `false`
        :param pulumi.Input[_builtins.str] name: Policy Rule Name
        :param pulumi.Input[_builtins.str] network_connection: Network selection mode: `ANYWHERE`, `ZONE`, `ON_NETWORK`, or `OFF_NETWORK`. Default: `ANYWHERE`
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] network_excludes: Required if `network_connection` = `ZONE`. Indicates the network zones to exclude.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] network_includes: Required if `network_connection` = `ZONE`. Indicates the network zones to include.
        :param pulumi.Input[_builtins.str] policy_id: Policy ID of the Rule
        :param pulumi.Input[_builtins.str] primary_factor: Rule's primary factor. **WARNING** Ony works as a part of the Identity Engine. Valid values: `PASSWORD_IDP_ANY_FACTOR`, `PASSWORD_IDP`.
        :param pulumi.Input[_builtins.int] priority: Rule priority. This attribute can be set to a valid priority. To avoid an endless diff situation an error is thrown if an invalid property is provided. The Okta API defaults to the last (lowest) if not provided.
        :param pulumi.Input[_builtins.str] risc_level: Risc level: ANY, LOW, MEDIUM or HIGH. Default: `ANY`
        :param pulumi.Input[_builtins.str] risk_level: Risk level: ANY, LOW, MEDIUM or HIGH. Default: `ANY`
        :param pulumi.Input[_builtins.int] session_idle: Max minutes a session can be idle. Default: `120`
        :param pulumi.Input[_builtins.int] session_lifetime: Max minutes a session is active: Disable = 0. Default: `120`
        :param pulumi.Input[_builtins.bool] session_persistent: Whether session cookies will last across browser sessions. Okta Administrators can never have persistent session cookies. Default: `false`
        :param pulumi.Input[_builtins.str] status: Policy Rule Status: `ACTIVE` or `INACTIVE`. Default: `ACTIVE`
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] users_excludeds: Set of User IDs to Exclude
        """
        if access is not None:
            pulumi.set(__self__, "access", access)
        if authtype is not None:
            pulumi.set(__self__, "authtype", authtype)
        if behaviors is not None:
            pulumi.set(__self__, "behaviors", behaviors)
        if factor_sequences is not None:
            pulumi.set(__self__, "factor_sequences", factor_sequences)
        if identity_provider is not None:
            pulumi.set(__self__, "identity_provider", identity_provider)
        if identity_provider_ids is not None:
            pulumi.set(__self__, "identity_provider_ids", identity_provider_ids)
        if mfa_lifetime is not None:
            pulumi.set(__self__, "mfa_lifetime", mfa_lifetime)
        if mfa_prompt is not None:
            pulumi.set(__self__, "mfa_prompt", mfa_prompt)
        if mfa_remember_device is not None:
            pulumi.set(__self__, "mfa_remember_device", mfa_remember_device)
        if mfa_required is not None:
            pulumi.set(__self__, "mfa_required", mfa_required)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if network_connection is not None:
            pulumi.set(__self__, "network_connection", network_connection)
        if network_excludes is not None:
            pulumi.set(__self__, "network_excludes", network_excludes)
        if network_includes is not None:
            pulumi.set(__self__, "network_includes", network_includes)
        if policy_id is not None:
            pulumi.set(__self__, "policy_id", policy_id)
        if primary_factor is not None:
            pulumi.set(__self__, "primary_factor", primary_factor)
        if priority is not None:
            pulumi.set(__self__, "priority", priority)
        if risc_level is not None:
            warnings.warn("""Attribute typo, switch to risk_level instead. Default: `ANY`""", DeprecationWarning)
            pulumi.log.warn("""risc_level is deprecated: Attribute typo, switch to risk_level instead. Default: `ANY`""")
        if risc_level is not None:
            pulumi.set(__self__, "risc_level", risc_level)
        if risk_level is not None:
            pulumi.set(__self__, "risk_level", risk_level)
        if session_idle is not None:
            pulumi.set(__self__, "session_idle", session_idle)
        if session_lifetime is not None:
            pulumi.set(__self__, "session_lifetime", session_lifetime)
        if session_persistent is not None:
            pulumi.set(__self__, "session_persistent", session_persistent)
        if status is not None:
            pulumi.set(__self__, "status", status)
        if users_excludeds is not None:
            pulumi.set(__self__, "users_excludeds", users_excludeds)

    @_builtins.property
    @pulumi.getter
    def access(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Allow or deny access based on the rule conditions: `ALLOW`, `DENY` or `CHALLENGE`. Default: `ALLOW`
        """
        return pulumi.get(self, "access")

    @access.setter
    def access(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "access", value)

    @_builtins.property
    @pulumi.getter
    def authtype(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Authentication entrypoint: `ANY`, `RADIUS` or `LDAP_INTERFACE`. Default: `ANY`
        """
        return pulumi.get(self, "authtype")

    @authtype.setter
    def authtype(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "authtype", value)

    @_builtins.property
    @pulumi.getter
    def behaviors(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]:
        """
        List of behavior IDs
        """
        return pulumi.get(self, "behaviors")

    @behaviors.setter
    def behaviors(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]):
        pulumi.set(self, "behaviors", value)

    @_builtins.property
    @pulumi.getter(name="factorSequences")
    def factor_sequences(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['RuleSignonFactorSequenceArgs']]]]:
        """
        Auth factor sequences. Should be set if 'access = "CHALLENGE"'.
        	- 'primary_criteria_provider' - (Required) Primary provider of the auth section.
        	- 'primary_criteria_factor_type' - (Required) Primary factor type of the auth section.
        	- 'secondary_criteria' - (Optional) Additional authentication steps.
        	- 'provider' - (Required) Provider of the additional authentication step.
        	- 'factor_type' - (Required) Factor type of the additional authentication step.
        """
        return pulumi.get(self, "factor_sequences")

    @factor_sequences.setter
    def factor_sequences(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['RuleSignonFactorSequenceArgs']]]]):
        pulumi.set(self, "factor_sequences", value)

    @_builtins.property
    @pulumi.getter(name="identityProvider")
    def identity_provider(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Apply rule based on the IdP used: `ANY`, `OKTA` or `SPECIFIC_IDP`. Default: `ANY`. > **WARNING**: Use of `identity_provider` requires a feature flag to be enabled.
        """
        return pulumi.get(self, "identity_provider")

    @identity_provider.setter
    def identity_provider(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "identity_provider", value)

    @_builtins.property
    @pulumi.getter(name="identityProviderIds")
    def identity_provider_ids(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]:
        """
        When identity_provider is `SPECIFIC_IDP` then this is the list of IdP IDs to apply the rule on
        """
        return pulumi.get(self, "identity_provider_ids")

    @identity_provider_ids.setter
    def identity_provider_ids(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]):
        pulumi.set(self, "identity_provider_ids", value)

    @_builtins.property
    @pulumi.getter(name="mfaLifetime")
    def mfa_lifetime(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        Elapsed time before the next MFA challenge
        """
        return pulumi.get(self, "mfa_lifetime")

    @mfa_lifetime.setter
    def mfa_lifetime(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "mfa_lifetime", value)

    @_builtins.property
    @pulumi.getter(name="mfaPrompt")
    def mfa_prompt(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Prompt for MFA based on the device used, a factor session lifetime, or every sign-on attempt: `DEVICE`, `SESSION` or`ALWAYS`.
        """
        return pulumi.get(self, "mfa_prompt")

    @mfa_prompt.setter
    def mfa_prompt(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "mfa_prompt", value)

    @_builtins.property
    @pulumi.getter(name="mfaRememberDevice")
    def mfa_remember_device(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Remember MFA device. Default: `false`
        """
        return pulumi.get(self, "mfa_remember_device")

    @mfa_remember_device.setter
    def mfa_remember_device(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "mfa_remember_device", value)

    @_builtins.property
    @pulumi.getter(name="mfaRequired")
    def mfa_required(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Require MFA. Default: `false`
        """
        return pulumi.get(self, "mfa_required")

    @mfa_required.setter
    def mfa_required(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "mfa_required", value)

    @_builtins.property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Policy Rule Name
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "name", value)

    @_builtins.property
    @pulumi.getter(name="networkConnection")
    def network_connection(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Network selection mode: `ANYWHERE`, `ZONE`, `ON_NETWORK`, or `OFF_NETWORK`. Default: `ANYWHERE`
        """
        return pulumi.get(self, "network_connection")

    @network_connection.setter
    def network_connection(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "network_connection", value)

    @_builtins.property
    @pulumi.getter(name="networkExcludes")
    def network_excludes(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]:
        """
        Required if `network_connection` = `ZONE`. Indicates the network zones to exclude.
        """
        return pulumi.get(self, "network_excludes")

    @network_excludes.setter
    def network_excludes(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]):
        pulumi.set(self, "network_excludes", value)

    @_builtins.property
    @pulumi.getter(name="networkIncludes")
    def network_includes(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]:
        """
        Required if `network_connection` = `ZONE`. Indicates the network zones to include.
        """
        return pulumi.get(self, "network_includes")

    @network_includes.setter
    def network_includes(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]):
        pulumi.set(self, "network_includes", value)

    @_builtins.property
    @pulumi.getter(name="policyId")
    def policy_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Policy ID of the Rule
        """
        return pulumi.get(self, "policy_id")

    @policy_id.setter
    def policy_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "policy_id", value)

    @_builtins.property
    @pulumi.getter(name="primaryFactor")
    def primary_factor(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Rule's primary factor. **WARNING** Ony works as a part of the Identity Engine. Valid values: `PASSWORD_IDP_ANY_FACTOR`, `PASSWORD_IDP`.
        """
        return pulumi.get(self, "primary_factor")

    @primary_factor.setter
    def primary_factor(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "primary_factor", value)

    @_builtins.property
    @pulumi.getter
    def priority(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        Rule priority. This attribute can be set to a valid priority. To avoid an endless diff situation an error is thrown if an invalid property is provided. The Okta API defaults to the last (lowest) if not provided.
        """
        return pulumi.get(self, "priority")

    @priority.setter
    def priority(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "priority", value)

    @_builtins.property
    @pulumi.getter(name="riscLevel")
    @_utilities.deprecated("""Attribute typo, switch to risk_level instead. Default: `ANY`""")
    def risc_level(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Risc level: ANY, LOW, MEDIUM or HIGH. Default: `ANY`
        """
        return pulumi.get(self, "risc_level")

    @risc_level.setter
    def risc_level(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "risc_level", value)

    @_builtins.property
    @pulumi.getter(name="riskLevel")
    def risk_level(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Risk level: ANY, LOW, MEDIUM or HIGH. Default: `ANY`
        """
        return pulumi.get(self, "risk_level")

    @risk_level.setter
    def risk_level(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "risk_level", value)

    @_builtins.property
    @pulumi.getter(name="sessionIdle")
    def session_idle(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        Max minutes a session can be idle. Default: `120`
        """
        return pulumi.get(self, "session_idle")

    @session_idle.setter
    def session_idle(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "session_idle", value)

    @_builtins.property
    @pulumi.getter(name="sessionLifetime")
    def session_lifetime(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        Max minutes a session is active: Disable = 0. Default: `120`
        """
        return pulumi.get(self, "session_lifetime")

    @session_lifetime.setter
    def session_lifetime(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "session_lifetime", value)

    @_builtins.property
    @pulumi.getter(name="sessionPersistent")
    def session_persistent(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Whether session cookies will last across browser sessions. Okta Administrators can never have persistent session cookies. Default: `false`
        """
        return pulumi.get(self, "session_persistent")

    @session_persistent.setter
    def session_persistent(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "session_persistent", value)

    @_builtins.property
    @pulumi.getter
    def status(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Policy Rule Status: `ACTIVE` or `INACTIVE`. Default: `ACTIVE`
        """
        return pulumi.get(self, "status")

    @status.setter
    def status(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "status", value)

    @_builtins.property
    @pulumi.getter(name="usersExcludeds")
    def users_excludeds(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]:
        """
        Set of User IDs to Exclude
        """
        return pulumi.get(self, "users_excludeds")

    @users_excludeds.setter
    def users_excludeds(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]):
        pulumi.set(self, "users_excludeds", value)


@pulumi.type_token("okta:policy/ruleSignon:RuleSignon")
class RuleSignon(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 access: Optional[pulumi.Input[_builtins.str]] = None,
                 authtype: Optional[pulumi.Input[_builtins.str]] = None,
                 behaviors: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 factor_sequences: Optional[pulumi.Input[Sequence[pulumi.Input[Union['RuleSignonFactorSequenceArgs', 'RuleSignonFactorSequenceArgsDict']]]]] = None,
                 identity_provider: Optional[pulumi.Input[_builtins.str]] = None,
                 identity_provider_ids: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 mfa_lifetime: Optional[pulumi.Input[_builtins.int]] = None,
                 mfa_prompt: Optional[pulumi.Input[_builtins.str]] = None,
                 mfa_remember_device: Optional[pulumi.Input[_builtins.bool]] = None,
                 mfa_required: Optional[pulumi.Input[_builtins.bool]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 network_connection: Optional[pulumi.Input[_builtins.str]] = None,
                 network_excludes: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 network_includes: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 policy_id: Optional[pulumi.Input[_builtins.str]] = None,
                 primary_factor: Optional[pulumi.Input[_builtins.str]] = None,
                 priority: Optional[pulumi.Input[_builtins.int]] = None,
                 risc_level: Optional[pulumi.Input[_builtins.str]] = None,
                 risk_level: Optional[pulumi.Input[_builtins.str]] = None,
                 session_idle: Optional[pulumi.Input[_builtins.int]] = None,
                 session_lifetime: Optional[pulumi.Input[_builtins.int]] = None,
                 session_persistent: Optional[pulumi.Input[_builtins.bool]] = None,
                 status: Optional[pulumi.Input[_builtins.str]] = None,
                 users_excludeds: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 __props__=None):
        """
        Creates a Sign On Policy Rule. In case `Invalid condition type specified: riskScore.` error is thrown, set `risc_level` to an empty string, since this feature is not enabled.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_okta as okta

        test = okta.policy.Signon("test",
            name="Example Policy",
            status="ACTIVE",
            description="Example Policy")
        new_city = okta.get_behaviour(name="New City")
        example = okta.policy.RuleSignon("example",
            access="CHALLENGE",
            authtype="RADIUS",
            name="Example Policy Rule",
            network_connection="ANYWHERE",
            policy_id=example_okta_policy_signon["id"],
            status="ACTIVE",
            risc_level="HIGH",
            behaviors=[new_city.id],
            factor_sequences=[
                {
                    "primary_criteria_factor_type": "token:hotp",
                    "primary_criteria_provider": "CUSTOM",
                    "secondary_criterias": [
                        {
                            "factor_type": "token:software:totp",
                            "provider": "OKTA",
                        },
                        {
                            "factor_type": "push",
                            "provider": "OKTA",
                        },
                        {
                            "factor_type": "password",
                            "provider": "OKTA",
                        },
                        {
                            "factor_type": "question",
                            "provider": "OKTA",
                        },
                        {
                            "factor_type": "sms",
                            "provider": "OKTA",
                        },
                        {
                            "factor_type": "token:software:totp",
                            "provider": "GOOGLE",
                        },
                        {
                            "factor_type": "email",
                            "provider": "OKTA",
                        },
                        {
                            "factor_type": "call",
                            "provider": "OKTA",
                        },
                        {
                            "factor_type": "webauthn",
                            "provider": "FIDO",
                        },
                        {
                            "factor_type": "token",
                            "provider": "RSA",
                        },
                        {
                            "factor_type": "token",
                            "provider": "SYMANTEC",
                        },
                    ],
                },
                {
                    "primary_criteria_factor_type": "token:software:totp",
                    "primary_criteria_provider": "OKTA",
                },
            ])
        ```

        ## Import

        ```sh
        $ pulumi import okta:policy/ruleSignon:RuleSignon example <policy_id>/<rule_id>
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] access: Allow or deny access based on the rule conditions: `ALLOW`, `DENY` or `CHALLENGE`. Default: `ALLOW`
        :param pulumi.Input[_builtins.str] authtype: Authentication entrypoint: `ANY`, `RADIUS` or `LDAP_INTERFACE`. Default: `ANY`
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] behaviors: List of behavior IDs
        :param pulumi.Input[Sequence[pulumi.Input[Union['RuleSignonFactorSequenceArgs', 'RuleSignonFactorSequenceArgsDict']]]] factor_sequences: Auth factor sequences. Should be set if 'access = "CHALLENGE"'.
               	- 'primary_criteria_provider' - (Required) Primary provider of the auth section.
               	- 'primary_criteria_factor_type' - (Required) Primary factor type of the auth section.
               	- 'secondary_criteria' - (Optional) Additional authentication steps.
               	- 'provider' - (Required) Provider of the additional authentication step.
               	- 'factor_type' - (Required) Factor type of the additional authentication step.
        :param pulumi.Input[_builtins.str] identity_provider: Apply rule based on the IdP used: `ANY`, `OKTA` or `SPECIFIC_IDP`. Default: `ANY`. > **WARNING**: Use of `identity_provider` requires a feature flag to be enabled.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] identity_provider_ids: When identity_provider is `SPECIFIC_IDP` then this is the list of IdP IDs to apply the rule on
        :param pulumi.Input[_builtins.int] mfa_lifetime: Elapsed time before the next MFA challenge
        :param pulumi.Input[_builtins.str] mfa_prompt: Prompt for MFA based on the device used, a factor session lifetime, or every sign-on attempt: `DEVICE`, `SESSION` or`ALWAYS`.
        :param pulumi.Input[_builtins.bool] mfa_remember_device: Remember MFA device. Default: `false`
        :param pulumi.Input[_builtins.bool] mfa_required: Require MFA. Default: `false`
        :param pulumi.Input[_builtins.str] name: Policy Rule Name
        :param pulumi.Input[_builtins.str] network_connection: Network selection mode: `ANYWHERE`, `ZONE`, `ON_NETWORK`, or `OFF_NETWORK`. Default: `ANYWHERE`
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] network_excludes: Required if `network_connection` = `ZONE`. Indicates the network zones to exclude.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] network_includes: Required if `network_connection` = `ZONE`. Indicates the network zones to include.
        :param pulumi.Input[_builtins.str] policy_id: Policy ID of the Rule
        :param pulumi.Input[_builtins.str] primary_factor: Rule's primary factor. **WARNING** Ony works as a part of the Identity Engine. Valid values: `PASSWORD_IDP_ANY_FACTOR`, `PASSWORD_IDP`.
        :param pulumi.Input[_builtins.int] priority: Rule priority. This attribute can be set to a valid priority. To avoid an endless diff situation an error is thrown if an invalid property is provided. The Okta API defaults to the last (lowest) if not provided.
        :param pulumi.Input[_builtins.str] risc_level: Risc level: ANY, LOW, MEDIUM or HIGH. Default: `ANY`
        :param pulumi.Input[_builtins.str] risk_level: Risk level: ANY, LOW, MEDIUM or HIGH. Default: `ANY`
        :param pulumi.Input[_builtins.int] session_idle: Max minutes a session can be idle. Default: `120`
        :param pulumi.Input[_builtins.int] session_lifetime: Max minutes a session is active: Disable = 0. Default: `120`
        :param pulumi.Input[_builtins.bool] session_persistent: Whether session cookies will last across browser sessions. Okta Administrators can never have persistent session cookies. Default: `false`
        :param pulumi.Input[_builtins.str] status: Policy Rule Status: `ACTIVE` or `INACTIVE`. Default: `ACTIVE`
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] users_excludeds: Set of User IDs to Exclude
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: Optional[RuleSignonArgs] = None,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Creates a Sign On Policy Rule. In case `Invalid condition type specified: riskScore.` error is thrown, set `risc_level` to an empty string, since this feature is not enabled.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_okta as okta

        test = okta.policy.Signon("test",
            name="Example Policy",
            status="ACTIVE",
            description="Example Policy")
        new_city = okta.get_behaviour(name="New City")
        example = okta.policy.RuleSignon("example",
            access="CHALLENGE",
            authtype="RADIUS",
            name="Example Policy Rule",
            network_connection="ANYWHERE",
            policy_id=example_okta_policy_signon["id"],
            status="ACTIVE",
            risc_level="HIGH",
            behaviors=[new_city.id],
            factor_sequences=[
                {
                    "primary_criteria_factor_type": "token:hotp",
                    "primary_criteria_provider": "CUSTOM",
                    "secondary_criterias": [
                        {
                            "factor_type": "token:software:totp",
                            "provider": "OKTA",
                        },
                        {
                            "factor_type": "push",
                            "provider": "OKTA",
                        },
                        {
                            "factor_type": "password",
                            "provider": "OKTA",
                        },
                        {
                            "factor_type": "question",
                            "provider": "OKTA",
                        },
                        {
                            "factor_type": "sms",
                            "provider": "OKTA",
                        },
                        {
                            "factor_type": "token:software:totp",
                            "provider": "GOOGLE",
                        },
                        {
                            "factor_type": "email",
                            "provider": "OKTA",
                        },
                        {
                            "factor_type": "call",
                            "provider": "OKTA",
                        },
                        {
                            "factor_type": "webauthn",
                            "provider": "FIDO",
                        },
                        {
                            "factor_type": "token",
                            "provider": "RSA",
                        },
                        {
                            "factor_type": "token",
                            "provider": "SYMANTEC",
                        },
                    ],
                },
                {
                    "primary_criteria_factor_type": "token:software:totp",
                    "primary_criteria_provider": "OKTA",
                },
            ])
        ```

        ## Import

        ```sh
        $ pulumi import okta:policy/ruleSignon:RuleSignon example <policy_id>/<rule_id>
        ```

        :param str resource_name: The name of the resource.
        :param RuleSignonArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(RuleSignonArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 access: Optional[pulumi.Input[_builtins.str]] = None,
                 authtype: Optional[pulumi.Input[_builtins.str]] = None,
                 behaviors: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 factor_sequences: Optional[pulumi.Input[Sequence[pulumi.Input[Union['RuleSignonFactorSequenceArgs', 'RuleSignonFactorSequenceArgsDict']]]]] = None,
                 identity_provider: Optional[pulumi.Input[_builtins.str]] = None,
                 identity_provider_ids: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 mfa_lifetime: Optional[pulumi.Input[_builtins.int]] = None,
                 mfa_prompt: Optional[pulumi.Input[_builtins.str]] = None,
                 mfa_remember_device: Optional[pulumi.Input[_builtins.bool]] = None,
                 mfa_required: Optional[pulumi.Input[_builtins.bool]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 network_connection: Optional[pulumi.Input[_builtins.str]] = None,
                 network_excludes: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 network_includes: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 policy_id: Optional[pulumi.Input[_builtins.str]] = None,
                 primary_factor: Optional[pulumi.Input[_builtins.str]] = None,
                 priority: Optional[pulumi.Input[_builtins.int]] = None,
                 risc_level: Optional[pulumi.Input[_builtins.str]] = None,
                 risk_level: Optional[pulumi.Input[_builtins.str]] = None,
                 session_idle: Optional[pulumi.Input[_builtins.int]] = None,
                 session_lifetime: Optional[pulumi.Input[_builtins.int]] = None,
                 session_persistent: Optional[pulumi.Input[_builtins.bool]] = None,
                 status: Optional[pulumi.Input[_builtins.str]] = None,
                 users_excludeds: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = RuleSignonArgs.__new__(RuleSignonArgs)

            __props__.__dict__["access"] = access
            __props__.__dict__["authtype"] = authtype
            __props__.__dict__["behaviors"] = behaviors
            __props__.__dict__["factor_sequences"] = factor_sequences
            __props__.__dict__["identity_provider"] = identity_provider
            __props__.__dict__["identity_provider_ids"] = identity_provider_ids
            __props__.__dict__["mfa_lifetime"] = mfa_lifetime
            __props__.__dict__["mfa_prompt"] = mfa_prompt
            __props__.__dict__["mfa_remember_device"] = mfa_remember_device
            __props__.__dict__["mfa_required"] = mfa_required
            __props__.__dict__["name"] = name
            __props__.__dict__["network_connection"] = network_connection
            __props__.__dict__["network_excludes"] = network_excludes
            __props__.__dict__["network_includes"] = network_includes
            __props__.__dict__["policy_id"] = policy_id
            __props__.__dict__["primary_factor"] = primary_factor
            __props__.__dict__["priority"] = priority
            __props__.__dict__["risc_level"] = risc_level
            __props__.__dict__["risk_level"] = risk_level
            __props__.__dict__["session_idle"] = session_idle
            __props__.__dict__["session_lifetime"] = session_lifetime
            __props__.__dict__["session_persistent"] = session_persistent
            __props__.__dict__["status"] = status
            __props__.__dict__["users_excludeds"] = users_excludeds
        super(RuleSignon, __self__).__init__(
            'okta:policy/ruleSignon:RuleSignon',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            access: Optional[pulumi.Input[_builtins.str]] = None,
            authtype: Optional[pulumi.Input[_builtins.str]] = None,
            behaviors: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
            factor_sequences: Optional[pulumi.Input[Sequence[pulumi.Input[Union['RuleSignonFactorSequenceArgs', 'RuleSignonFactorSequenceArgsDict']]]]] = None,
            identity_provider: Optional[pulumi.Input[_builtins.str]] = None,
            identity_provider_ids: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
            mfa_lifetime: Optional[pulumi.Input[_builtins.int]] = None,
            mfa_prompt: Optional[pulumi.Input[_builtins.str]] = None,
            mfa_remember_device: Optional[pulumi.Input[_builtins.bool]] = None,
            mfa_required: Optional[pulumi.Input[_builtins.bool]] = None,
            name: Optional[pulumi.Input[_builtins.str]] = None,
            network_connection: Optional[pulumi.Input[_builtins.str]] = None,
            network_excludes: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
            network_includes: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
            policy_id: Optional[pulumi.Input[_builtins.str]] = None,
            primary_factor: Optional[pulumi.Input[_builtins.str]] = None,
            priority: Optional[pulumi.Input[_builtins.int]] = None,
            risc_level: Optional[pulumi.Input[_builtins.str]] = None,
            risk_level: Optional[pulumi.Input[_builtins.str]] = None,
            session_idle: Optional[pulumi.Input[_builtins.int]] = None,
            session_lifetime: Optional[pulumi.Input[_builtins.int]] = None,
            session_persistent: Optional[pulumi.Input[_builtins.bool]] = None,
            status: Optional[pulumi.Input[_builtins.str]] = None,
            users_excludeds: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None) -> 'RuleSignon':
        """
        Get an existing RuleSignon resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] access: Allow or deny access based on the rule conditions: `ALLOW`, `DENY` or `CHALLENGE`. Default: `ALLOW`
        :param pulumi.Input[_builtins.str] authtype: Authentication entrypoint: `ANY`, `RADIUS` or `LDAP_INTERFACE`. Default: `ANY`
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] behaviors: List of behavior IDs
        :param pulumi.Input[Sequence[pulumi.Input[Union['RuleSignonFactorSequenceArgs', 'RuleSignonFactorSequenceArgsDict']]]] factor_sequences: Auth factor sequences. Should be set if 'access = "CHALLENGE"'.
               	- 'primary_criteria_provider' - (Required) Primary provider of the auth section.
               	- 'primary_criteria_factor_type' - (Required) Primary factor type of the auth section.
               	- 'secondary_criteria' - (Optional) Additional authentication steps.
               	- 'provider' - (Required) Provider of the additional authentication step.
               	- 'factor_type' - (Required) Factor type of the additional authentication step.
        :param pulumi.Input[_builtins.str] identity_provider: Apply rule based on the IdP used: `ANY`, `OKTA` or `SPECIFIC_IDP`. Default: `ANY`. > **WARNING**: Use of `identity_provider` requires a feature flag to be enabled.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] identity_provider_ids: When identity_provider is `SPECIFIC_IDP` then this is the list of IdP IDs to apply the rule on
        :param pulumi.Input[_builtins.int] mfa_lifetime: Elapsed time before the next MFA challenge
        :param pulumi.Input[_builtins.str] mfa_prompt: Prompt for MFA based on the device used, a factor session lifetime, or every sign-on attempt: `DEVICE`, `SESSION` or`ALWAYS`.
        :param pulumi.Input[_builtins.bool] mfa_remember_device: Remember MFA device. Default: `false`
        :param pulumi.Input[_builtins.bool] mfa_required: Require MFA. Default: `false`
        :param pulumi.Input[_builtins.str] name: Policy Rule Name
        :param pulumi.Input[_builtins.str] network_connection: Network selection mode: `ANYWHERE`, `ZONE`, `ON_NETWORK`, or `OFF_NETWORK`. Default: `ANYWHERE`
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] network_excludes: Required if `network_connection` = `ZONE`. Indicates the network zones to exclude.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] network_includes: Required if `network_connection` = `ZONE`. Indicates the network zones to include.
        :param pulumi.Input[_builtins.str] policy_id: Policy ID of the Rule
        :param pulumi.Input[_builtins.str] primary_factor: Rule's primary factor. **WARNING** Ony works as a part of the Identity Engine. Valid values: `PASSWORD_IDP_ANY_FACTOR`, `PASSWORD_IDP`.
        :param pulumi.Input[_builtins.int] priority: Rule priority. This attribute can be set to a valid priority. To avoid an endless diff situation an error is thrown if an invalid property is provided. The Okta API defaults to the last (lowest) if not provided.
        :param pulumi.Input[_builtins.str] risc_level: Risc level: ANY, LOW, MEDIUM or HIGH. Default: `ANY`
        :param pulumi.Input[_builtins.str] risk_level: Risk level: ANY, LOW, MEDIUM or HIGH. Default: `ANY`
        :param pulumi.Input[_builtins.int] session_idle: Max minutes a session can be idle. Default: `120`
        :param pulumi.Input[_builtins.int] session_lifetime: Max minutes a session is active: Disable = 0. Default: `120`
        :param pulumi.Input[_builtins.bool] session_persistent: Whether session cookies will last across browser sessions. Okta Administrators can never have persistent session cookies. Default: `false`
        :param pulumi.Input[_builtins.str] status: Policy Rule Status: `ACTIVE` or `INACTIVE`. Default: `ACTIVE`
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] users_excludeds: Set of User IDs to Exclude
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _RuleSignonState.__new__(_RuleSignonState)

        __props__.__dict__["access"] = access
        __props__.__dict__["authtype"] = authtype
        __props__.__dict__["behaviors"] = behaviors
        __props__.__dict__["factor_sequences"] = factor_sequences
        __props__.__dict__["identity_provider"] = identity_provider
        __props__.__dict__["identity_provider_ids"] = identity_provider_ids
        __props__.__dict__["mfa_lifetime"] = mfa_lifetime
        __props__.__dict__["mfa_prompt"] = mfa_prompt
        __props__.__dict__["mfa_remember_device"] = mfa_remember_device
        __props__.__dict__["mfa_required"] = mfa_required
        __props__.__dict__["name"] = name
        __props__.__dict__["network_connection"] = network_connection
        __props__.__dict__["network_excludes"] = network_excludes
        __props__.__dict__["network_includes"] = network_includes
        __props__.__dict__["policy_id"] = policy_id
        __props__.__dict__["primary_factor"] = primary_factor
        __props__.__dict__["priority"] = priority
        __props__.__dict__["risc_level"] = risc_level
        __props__.__dict__["risk_level"] = risk_level
        __props__.__dict__["session_idle"] = session_idle
        __props__.__dict__["session_lifetime"] = session_lifetime
        __props__.__dict__["session_persistent"] = session_persistent
        __props__.__dict__["status"] = status
        __props__.__dict__["users_excludeds"] = users_excludeds
        return RuleSignon(resource_name, opts=opts, __props__=__props__)

    @_builtins.property
    @pulumi.getter
    def access(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        Allow or deny access based on the rule conditions: `ALLOW`, `DENY` or `CHALLENGE`. Default: `ALLOW`
        """
        return pulumi.get(self, "access")

    @_builtins.property
    @pulumi.getter
    def authtype(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        Authentication entrypoint: `ANY`, `RADIUS` or `LDAP_INTERFACE`. Default: `ANY`
        """
        return pulumi.get(self, "authtype")

    @_builtins.property
    @pulumi.getter
    def behaviors(self) -> pulumi.Output[Optional[Sequence[_builtins.str]]]:
        """
        List of behavior IDs
        """
        return pulumi.get(self, "behaviors")

    @_builtins.property
    @pulumi.getter(name="factorSequences")
    def factor_sequences(self) -> pulumi.Output[Optional[Sequence['outputs.RuleSignonFactorSequence']]]:
        """
        Auth factor sequences. Should be set if 'access = "CHALLENGE"'.
        	- 'primary_criteria_provider' - (Required) Primary provider of the auth section.
        	- 'primary_criteria_factor_type' - (Required) Primary factor type of the auth section.
        	- 'secondary_criteria' - (Optional) Additional authentication steps.
        	- 'provider' - (Required) Provider of the additional authentication step.
        	- 'factor_type' - (Required) Factor type of the additional authentication step.
        """
        return pulumi.get(self, "factor_sequences")

    @_builtins.property
    @pulumi.getter(name="identityProvider")
    def identity_provider(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        Apply rule based on the IdP used: `ANY`, `OKTA` or `SPECIFIC_IDP`. Default: `ANY`. > **WARNING**: Use of `identity_provider` requires a feature flag to be enabled.
        """
        return pulumi.get(self, "identity_provider")

    @_builtins.property
    @pulumi.getter(name="identityProviderIds")
    def identity_provider_ids(self) -> pulumi.Output[Optional[Sequence[_builtins.str]]]:
        """
        When identity_provider is `SPECIFIC_IDP` then this is the list of IdP IDs to apply the rule on
        """
        return pulumi.get(self, "identity_provider_ids")

    @_builtins.property
    @pulumi.getter(name="mfaLifetime")
    def mfa_lifetime(self) -> pulumi.Output[Optional[_builtins.int]]:
        """
        Elapsed time before the next MFA challenge
        """
        return pulumi.get(self, "mfa_lifetime")

    @_builtins.property
    @pulumi.getter(name="mfaPrompt")
    def mfa_prompt(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        Prompt for MFA based on the device used, a factor session lifetime, or every sign-on attempt: `DEVICE`, `SESSION` or`ALWAYS`.
        """
        return pulumi.get(self, "mfa_prompt")

    @_builtins.property
    @pulumi.getter(name="mfaRememberDevice")
    def mfa_remember_device(self) -> pulumi.Output[Optional[_builtins.bool]]:
        """
        Remember MFA device. Default: `false`
        """
        return pulumi.get(self, "mfa_remember_device")

    @_builtins.property
    @pulumi.getter(name="mfaRequired")
    def mfa_required(self) -> pulumi.Output[Optional[_builtins.bool]]:
        """
        Require MFA. Default: `false`
        """
        return pulumi.get(self, "mfa_required")

    @_builtins.property
    @pulumi.getter
    def name(self) -> pulumi.Output[_builtins.str]:
        """
        Policy Rule Name
        """
        return pulumi.get(self, "name")

    @_builtins.property
    @pulumi.getter(name="networkConnection")
    def network_connection(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        Network selection mode: `ANYWHERE`, `ZONE`, `ON_NETWORK`, or `OFF_NETWORK`. Default: `ANYWHERE`
        """
        return pulumi.get(self, "network_connection")

    @_builtins.property
    @pulumi.getter(name="networkExcludes")
    def network_excludes(self) -> pulumi.Output[Optional[Sequence[_builtins.str]]]:
        """
        Required if `network_connection` = `ZONE`. Indicates the network zones to exclude.
        """
        return pulumi.get(self, "network_excludes")

    @_builtins.property
    @pulumi.getter(name="networkIncludes")
    def network_includes(self) -> pulumi.Output[Optional[Sequence[_builtins.str]]]:
        """
        Required if `network_connection` = `ZONE`. Indicates the network zones to include.
        """
        return pulumi.get(self, "network_includes")

    @_builtins.property
    @pulumi.getter(name="policyId")
    def policy_id(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        Policy ID of the Rule
        """
        return pulumi.get(self, "policy_id")

    @_builtins.property
    @pulumi.getter(name="primaryFactor")
    def primary_factor(self) -> pulumi.Output[_builtins.str]:
        """
        Rule's primary factor. **WARNING** Ony works as a part of the Identity Engine. Valid values: `PASSWORD_IDP_ANY_FACTOR`, `PASSWORD_IDP`.
        """
        return pulumi.get(self, "primary_factor")

    @_builtins.property
    @pulumi.getter
    def priority(self) -> pulumi.Output[Optional[_builtins.int]]:
        """
        Rule priority. This attribute can be set to a valid priority. To avoid an endless diff situation an error is thrown if an invalid property is provided. The Okta API defaults to the last (lowest) if not provided.
        """
        return pulumi.get(self, "priority")

    @_builtins.property
    @pulumi.getter(name="riscLevel")
    @_utilities.deprecated("""Attribute typo, switch to risk_level instead. Default: `ANY`""")
    def risc_level(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        Risc level: ANY, LOW, MEDIUM or HIGH. Default: `ANY`
        """
        return pulumi.get(self, "risc_level")

    @_builtins.property
    @pulumi.getter(name="riskLevel")
    def risk_level(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        Risk level: ANY, LOW, MEDIUM or HIGH. Default: `ANY`
        """
        return pulumi.get(self, "risk_level")

    @_builtins.property
    @pulumi.getter(name="sessionIdle")
    def session_idle(self) -> pulumi.Output[Optional[_builtins.int]]:
        """
        Max minutes a session can be idle. Default: `120`
        """
        return pulumi.get(self, "session_idle")

    @_builtins.property
    @pulumi.getter(name="sessionLifetime")
    def session_lifetime(self) -> pulumi.Output[Optional[_builtins.int]]:
        """
        Max minutes a session is active: Disable = 0. Default: `120`
        """
        return pulumi.get(self, "session_lifetime")

    @_builtins.property
    @pulumi.getter(name="sessionPersistent")
    def session_persistent(self) -> pulumi.Output[Optional[_builtins.bool]]:
        """
        Whether session cookies will last across browser sessions. Okta Administrators can never have persistent session cookies. Default: `false`
        """
        return pulumi.get(self, "session_persistent")

    @_builtins.property
    @pulumi.getter
    def status(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        Policy Rule Status: `ACTIVE` or `INACTIVE`. Default: `ACTIVE`
        """
        return pulumi.get(self, "status")

    @_builtins.property
    @pulumi.getter(name="usersExcludeds")
    def users_excludeds(self) -> pulumi.Output[Optional[Sequence[_builtins.str]]]:
        """
        Set of User IDs to Exclude
        """
        return pulumi.get(self, "users_excludeds")




# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = [
    'MappingMapping',
]

@pulumi.output_type
class MappingMapping(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "pushStatus":
            suggest = "push_status"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in MappingMapping. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        MappingMapping.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        MappingMapping.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 expression: _builtins.str,
                 id: _builtins.str,
                 push_status: Optional[_builtins.str] = None):
        """
        :param _builtins.str id: The mapping property key.
        """
        pulumi.set(__self__, "expression", expression)
        pulumi.set(__self__, "id", id)
        if push_status is not None:
            pulumi.set(__self__, "push_status", push_status)

    @_builtins.property
    @pulumi.getter
    def expression(self) -> _builtins.str:
        return pulumi.get(self, "expression")

    @_builtins.property
    @pulumi.getter
    def id(self) -> _builtins.str:
        """
        The mapping property key.
        """
        return pulumi.get(self, "id")

    @_builtins.property
    @pulumi.getter(name="pushStatus")
    def push_status(self) -> Optional[_builtins.str]:
        return pulumi.get(self, "push_status")





# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
from .. import _utilities
import typing
# Export this package's modules as members:
from .device_assurance_android import *
from .device_assurance_chromeos import *
from .device_assurance_ios import *
from .device_assurance_macos import *
from .device_assurance_windows import *
from .get_default_policy import *
from .get_policy import *
from .mfa import *
from .password import *
from .rule_idp_discovery import *
from .rule_mfa import *
from .rule_password import *
from .rule_signon import *
from .signon import *
from ._inputs import *
from . import outputs



# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities

__all__ = ['UserGroupMembershipsArgs', 'UserGroupMemberships']

@pulumi.input_type
class UserGroupMembershipsArgs:
    def __init__(__self__, *,
                 groups: pulumi.Input[Sequence[pulumi.Input[_builtins.str]]],
                 user_id: pulumi.Input[_builtins.str]):
        """
        The set of arguments for constructing a UserGroupMemberships resource.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] groups: The list of Okta group IDs which the user should have membership managed for.
        :param pulumi.Input[_builtins.str] user_id: ID of a Okta User
        """
        pulumi.set(__self__, "groups", groups)
        pulumi.set(__self__, "user_id", user_id)

    @_builtins.property
    @pulumi.getter
    def groups(self) -> pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]:
        """
        The list of Okta group IDs which the user should have membership managed for.
        """
        return pulumi.get(self, "groups")

    @groups.setter
    def groups(self, value: pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]):
        pulumi.set(self, "groups", value)

    @_builtins.property
    @pulumi.getter(name="userId")
    def user_id(self) -> pulumi.Input[_builtins.str]:
        """
        ID of a Okta User
        """
        return pulumi.get(self, "user_id")

    @user_id.setter
    def user_id(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "user_id", value)


@pulumi.input_type
class _UserGroupMembershipsState:
    def __init__(__self__, *,
                 groups: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 user_id: Optional[pulumi.Input[_builtins.str]] = None):
        """
        Input properties used for looking up and filtering UserGroupMemberships resources.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] groups: The list of Okta group IDs which the user should have membership managed for.
        :param pulumi.Input[_builtins.str] user_id: ID of a Okta User
        """
        if groups is not None:
            pulumi.set(__self__, "groups", groups)
        if user_id is not None:
            pulumi.set(__self__, "user_id", user_id)

    @_builtins.property
    @pulumi.getter
    def groups(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]:
        """
        The list of Okta group IDs which the user should have membership managed for.
        """
        return pulumi.get(self, "groups")

    @groups.setter
    def groups(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]):
        pulumi.set(self, "groups", value)

    @_builtins.property
    @pulumi.getter(name="userId")
    def user_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        ID of a Okta User
        """
        return pulumi.get(self, "user_id")

    @user_id.setter
    def user_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "user_id", value)


@pulumi.type_token("okta:index/userGroupMemberships:UserGroupMemberships")
class UserGroupMemberships(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 groups: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 user_id: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        """
        ## Example Usage

        ```python
        import pulumi
        import pulumi_okta as okta

        test = okta.user.User("test",
            first_name="TestAcc",
            last_name="Smith",
            login="testAcc-replace_with_uuid@example.com",
            email="testAcc-replace_with_uuid@example.com")
        test_user_group_memberships = okta.UserGroupMemberships("test",
            user_id=test.id,
            groups=[
                test1["id"],
                test2["id"],
            ])
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] groups: The list of Okta group IDs which the user should have membership managed for.
        :param pulumi.Input[_builtins.str] user_id: ID of a Okta User
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: UserGroupMembershipsArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        ## Example Usage

        ```python
        import pulumi
        import pulumi_okta as okta

        test = okta.user.User("test",
            first_name="TestAcc",
            last_name="Smith",
            login="testAcc-replace_with_uuid@example.com",
            email="testAcc-replace_with_uuid@example.com")
        test_user_group_memberships = okta.UserGroupMemberships("test",
            user_id=test.id,
            groups=[
                test1["id"],
                test2["id"],
            ])
        ```

        :param str resource_name: The name of the resource.
        :param UserGroupMembershipsArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(UserGroupMembershipsArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 groups: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 user_id: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = UserGroupMembershipsArgs.__new__(UserGroupMembershipsArgs)

            if groups is None and not opts.urn:
                raise TypeError("Missing required property 'groups'")
            __props__.__dict__["groups"] = groups
            if user_id is None and not opts.urn:
                raise TypeError("Missing required property 'user_id'")
            __props__.__dict__["user_id"] = user_id
        super(UserGroupMemberships, __self__).__init__(
            'okta:index/userGroupMemberships:UserGroupMemberships',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            groups: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
            user_id: Optional[pulumi.Input[_builtins.str]] = None) -> 'UserGroupMemberships':
        """
        Get an existing UserGroupMemberships resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] groups: The list of Okta group IDs which the user should have membership managed for.
        :param pulumi.Input[_builtins.str] user_id: ID of a Okta User
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _UserGroupMembershipsState.__new__(_UserGroupMembershipsState)

        __props__.__dict__["groups"] = groups
        __props__.__dict__["user_id"] = user_id
        return UserGroupMemberships(resource_name, opts=opts, __props__=__props__)

    @_builtins.property
    @pulumi.getter
    def groups(self) -> pulumi.Output[Sequence[_builtins.str]]:
        """
        The list of Okta group IDs which the user should have membership managed for.
        """
        return pulumi.get(self, "groups")

    @_builtins.property
    @pulumi.getter(name="userId")
    def user_id(self) -> pulumi.Output[_builtins.str]:
        """
        ID of a Okta User
        """
        return pulumi.get(self, "user_id")




# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = [
    'GetSamlResult',
    'AwaitableGetSamlResult',
    'get_saml',
    'get_saml_output',
]

@pulumi.output_type
class GetSamlResult:
    """
    A collection of values returned by getSaml.
    """
    def __init__(__self__, acs_binding=None, acs_type=None, audience=None, id=None, issuer=None, issuer_mode=None, kid=None, name=None, sso_binding=None, sso_destination=None, sso_url=None, subject_filter=None, subject_formats=None, type=None):
        if acs_binding and not isinstance(acs_binding, str):
            raise TypeError("Expected argument 'acs_binding' to be a str")
        pulumi.set(__self__, "acs_binding", acs_binding)
        if acs_type and not isinstance(acs_type, str):
            raise TypeError("Expected argument 'acs_type' to be a str")
        pulumi.set(__self__, "acs_type", acs_type)
        if audience and not isinstance(audience, str):
            raise TypeError("Expected argument 'audience' to be a str")
        pulumi.set(__self__, "audience", audience)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if issuer and not isinstance(issuer, str):
            raise TypeError("Expected argument 'issuer' to be a str")
        pulumi.set(__self__, "issuer", issuer)
        if issuer_mode and not isinstance(issuer_mode, str):
            raise TypeError("Expected argument 'issuer_mode' to be a str")
        pulumi.set(__self__, "issuer_mode", issuer_mode)
        if kid and not isinstance(kid, str):
            raise TypeError("Expected argument 'kid' to be a str")
        pulumi.set(__self__, "kid", kid)
        if name and not isinstance(name, str):
            raise TypeError("Expected argument 'name' to be a str")
        pulumi.set(__self__, "name", name)
        if sso_binding and not isinstance(sso_binding, str):
            raise TypeError("Expected argument 'sso_binding' to be a str")
        pulumi.set(__self__, "sso_binding", sso_binding)
        if sso_destination and not isinstance(sso_destination, str):
            raise TypeError("Expected argument 'sso_destination' to be a str")
        pulumi.set(__self__, "sso_destination", sso_destination)
        if sso_url and not isinstance(sso_url, str):
            raise TypeError("Expected argument 'sso_url' to be a str")
        pulumi.set(__self__, "sso_url", sso_url)
        if subject_filter and not isinstance(subject_filter, str):
            raise TypeError("Expected argument 'subject_filter' to be a str")
        pulumi.set(__self__, "subject_filter", subject_filter)
        if subject_formats and not isinstance(subject_formats, list):
            raise TypeError("Expected argument 'subject_formats' to be a list")
        pulumi.set(__self__, "subject_formats", subject_formats)
        if type and not isinstance(type, str):
            raise TypeError("Expected argument 'type' to be a str")
        pulumi.set(__self__, "type", type)

    @_builtins.property
    @pulumi.getter(name="acsBinding")
    def acs_binding(self) -> _builtins.str:
        """
        ACS binding
        """
        return pulumi.get(self, "acs_binding")

    @_builtins.property
    @pulumi.getter(name="acsType")
    def acs_type(self) -> _builtins.str:
        """
        Determines whether to publish an instance-specific (trust) or organization (shared) ACS endpoint in the SAML metadata.
        """
        return pulumi.get(self, "acs_type")

    @_builtins.property
    @pulumi.getter
    def audience(self) -> _builtins.str:
        """
        URI that identifies the target Okta IdP instance (SP)
        """
        return pulumi.get(self, "audience")

    @_builtins.property
    @pulumi.getter
    def id(self) -> Optional[_builtins.str]:
        """
        Id of idp.
        """
        return pulumi.get(self, "id")

    @_builtins.property
    @pulumi.getter
    def issuer(self) -> _builtins.str:
        """
        URI that identifies the issuer (IdP).
        """
        return pulumi.get(self, "issuer")

    @_builtins.property
    @pulumi.getter(name="issuerMode")
    def issuer_mode(self) -> _builtins.str:
        """
        Indicates whether Okta uses the original Okta org domain URL, or a custom domain URL in the request to the IdP.
        """
        return pulumi.get(self, "issuer_mode")

    @_builtins.property
    @pulumi.getter
    def kid(self) -> _builtins.str:
        """
        Key ID reference to the IdP's X.509 signature certificate.
        """
        return pulumi.get(self, "kid")

    @_builtins.property
    @pulumi.getter
    def name(self) -> Optional[_builtins.str]:
        """
        Name of the idp.
        """
        return pulumi.get(self, "name")

    @_builtins.property
    @pulumi.getter(name="ssoBinding")
    def sso_binding(self) -> _builtins.str:
        """
        Single sign-on binding.
        """
        return pulumi.get(self, "sso_binding")

    @_builtins.property
    @pulumi.getter(name="ssoDestination")
    def sso_destination(self) -> _builtins.str:
        """
        SSO request binding, HTTP-POST or HTTP-REDIRECT.
        """
        return pulumi.get(self, "sso_destination")

    @_builtins.property
    @pulumi.getter(name="ssoUrl")
    def sso_url(self) -> _builtins.str:
        """
        Single sign-on url.
        """
        return pulumi.get(self, "sso_url")

    @_builtins.property
    @pulumi.getter(name="subjectFilter")
    def subject_filter(self) -> _builtins.str:
        """
        Regular expression pattern used to filter untrusted IdP usernames.
        """
        return pulumi.get(self, "subject_filter")

    @_builtins.property
    @pulumi.getter(name="subjectFormats")
    def subject_formats(self) -> Sequence[_builtins.str]:
        """
        Expression to generate or transform a unique username for the IdP user.
        """
        return pulumi.get(self, "subject_formats")

    @_builtins.property
    @pulumi.getter
    def type(self) -> _builtins.str:
        """
        Type of idp.
        """
        return pulumi.get(self, "type")


class AwaitableGetSamlResult(GetSamlResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetSamlResult(
            acs_binding=self.acs_binding,
            acs_type=self.acs_type,
            audience=self.audience,
            id=self.id,
            issuer=self.issuer,
            issuer_mode=self.issuer_mode,
            kid=self.kid,
            name=self.name,
            sso_binding=self.sso_binding,
            sso_destination=self.sso_destination,
            sso_url=self.sso_url,
            subject_filter=self.subject_filter,
            subject_formats=self.subject_formats,
            type=self.type)


def get_saml(id: Optional[_builtins.str] = None,
             name: Optional[_builtins.str] = None,
             opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetSamlResult:
    """
    Get a SAML IdP from Okta.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_okta as okta

    example = okta.idp.get_saml(name="Example App")
    ```


    :param _builtins.str id: Id of idp.
    :param _builtins.str name: Name of the idp.
    """
    __args__ = dict()
    __args__['id'] = id
    __args__['name'] = name
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('okta:idp/getSaml:getSaml', __args__, opts=opts, typ=GetSamlResult).value

    return AwaitableGetSamlResult(
        acs_binding=pulumi.get(__ret__, 'acs_binding'),
        acs_type=pulumi.get(__ret__, 'acs_type'),
        audience=pulumi.get(__ret__, 'audience'),
        id=pulumi.get(__ret__, 'id'),
        issuer=pulumi.get(__ret__, 'issuer'),
        issuer_mode=pulumi.get(__ret__, 'issuer_mode'),
        kid=pulumi.get(__ret__, 'kid'),
        name=pulumi.get(__ret__, 'name'),
        sso_binding=pulumi.get(__ret__, 'sso_binding'),
        sso_destination=pulumi.get(__ret__, 'sso_destination'),
        sso_url=pulumi.get(__ret__, 'sso_url'),
        subject_filter=pulumi.get(__ret__, 'subject_filter'),
        subject_formats=pulumi.get(__ret__, 'subject_formats'),
        type=pulumi.get(__ret__, 'type'))
def get_saml_output(id: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                    name: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                    opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetSamlResult]:
    """
    Get a SAML IdP from Okta.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_okta as okta

    example = okta.idp.get_saml(name="Example App")
    ```


    :param _builtins.str id: Id of idp.
    :param _builtins.str name: Name of the idp.
    """
    __args__ = dict()
    __args__['id'] = id
    __args__['name'] = name
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('okta:idp/getSaml:getSaml', __args__, opts=opts, typ=GetSamlResult)
    return __ret__.apply(lambda __response__: GetSamlResult(
        acs_binding=pulumi.get(__response__, 'acs_binding'),
        acs_type=pulumi.get(__response__, 'acs_type'),
        audience=pulumi.get(__response__, 'audience'),
        id=pulumi.get(__response__, 'id'),
        issuer=pulumi.get(__response__, 'issuer'),
        issuer_mode=pulumi.get(__response__, 'issuer_mode'),
        kid=pulumi.get(__response__, 'kid'),
        name=pulumi.get(__response__, 'name'),
        sso_binding=pulumi.get(__response__, 'sso_binding'),
        sso_destination=pulumi.get(__response__, 'sso_destination'),
        sso_url=pulumi.get(__response__, 'sso_url'),
        subject_filter=pulumi.get(__response__, 'subject_filter'),
        subject_formats=pulumi.get(__response__, 'subject_formats'),
        type=pulumi.get(__response__, 'type')))
